(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    387063,      17823]*)
(*NotebookOutlinePosition[    387709,      17845]*)
(*  CellTagsIndexPosition[    387665,      17841]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Zerlegung der Einheit"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Im Rahmen dieses Exkurses soll das prinzipielle Ph\[ADoubleDot]nomen der \
Zerlegung des Einheitsintervalls durch eine diskrete \
Wahrscheinlichkeitsverteilung und die in Abb. 2.3 dargestellte Abfolge von \
Schritten zur praktischen Verwendung dieser Vorstellung in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " rekonstruiert werden. \n\nDas erste Element auf diesem Weg ist eine \
geeignete Wahrscheinlichkeitsverteilung. Dazu wird mit der Funktion ",
  StyleBox["Random[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", die eine im Intervall [0, 1] gleichverteilte reellwertige Zufallszahl \
erzeugt, der Ausgangspunkt gelegt:"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    StyleBox[\(\(\ \)\(SeedRandom[1]\)\(\ \)\),
      FontColor->GrayLevel[0.500008]]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rand = Table[Random[], {6}]\)], "Input"],

Cell[BoxData[
    \({0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
      0.12463419022903224`, 0.9345372830959425`, 
      0.6002520340808316`}\)], "Output"]
}, Open  ]],

Cell["\<\
Diese Tabelle aus sechs Zufallszahlen l\[ADoubleDot]sst sich nun so \
normieren, dass die Summe gerade Eins ist:\
\>", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(probDist = rand/Apply[Plus, rand]\)], "Input"],

Cell[BoxData[
    \({0.1696705704267232`, 0.21090429301674657`, 0.1983717253211976`, 
      0.03162402528244657`, 0.23712458526593577`, 
      0.15230480068695026`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Funktion ",
  StyleBox["Plus",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gibt die Summe ihrer Argumente aus, ",
  StyleBox["Plus[x1, x2, x3]= x1 + x2 + x3",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Um die Funktion ",
  StyleBox["Plus",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " auf eine Liste von Elementen anzuwenden, ist der Befehl ",
  StyleBox["Apply",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " n\[ODoubleDot]tig. ",
  StyleBox["Plus[{x1, x2, x3}]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " w\[UDoubleDot]rde das Argument unausgewertet lassen, erst ",
  StyleBox["Apply[Plus, {x1, x2, x3}] ",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "f\[UDoubleDot]hrt auf x1+ x2 + x3. Mit dem Anwenden der Funktion ",
  StyleBox["Plus",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " auf die resultierende Liste,"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[Plus, probDist]\)], "Input"],

Cell[BoxData[
    \(1.`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "l\[ADoubleDot]sst sich diese Normierung \
\[UDoubleDot]berpr\[UDoubleDot]fen. Eine Abk\[UDoubleDot]rzung dieses ",
  StyleBox["Apply",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehls ist durch ",
  StyleBox["@@",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " gegeben:"
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ probDist\)], "Input"],

Cell[BoxData[
    \(1.`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Damit sind die einzelnen Intervallgr\[ODoubleDot]\[SZ]en festgelegt. Durch \
Bildung der Partialsummen\n\n",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)],
    FontFamily->"Times New Roman"],
  StyleBox["=",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 1\)\%i p\_j\)],
    FontFamily->"Times New Roman"],
  "\n\nerh\[ADoubleDot]lt man daraus die Intervallgrenzen im \
Einheitsintervall [0, 1]. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sind Partialsummen effizient zu formulieren, indem man die Funktion ",
  StyleBox["Plus",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " iterativ auf eine Liste anwendet. Dazu verwenden wir die Funktion ",
  StyleBox["FoldList",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ". Diese Funktion besitzt drei Argumente, n\[ADoubleDot]mlich eine \
zweiargumentige Funktion ",
  StyleBox["f",
    FontSlant->"Italic"],
  " , das Anfangselement ",
  StyleBox["A",
    FontSlant->"Italic"],
  " und eine Liste",
  StyleBox[" L = {",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`L\_1\)]],
  StyleBox[", . . . , ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`L\_n\)]],
  StyleBox["}",
    FontSlant->"Italic"],
  ". Dann hat man \n\n",
  StyleBox["FoldList[f, A, L] ",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "= {A, f [A, L1], f [ f [A, L1], L2], . . . }. \n\nDie Iteration endet, \
wenn das letzte Listenelement erreicht ist. In unserem Fall bildet die untere \
Intervallgrenze, ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = 0, den Anfangspunkt. Man hat also"
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(cumDist = FoldList[Plus, 0, probDist]\)], "Input"],

Cell[BoxData[
    \({0, 0.1696705704267232`, 0.3805748634434698`, 0.5789465887646674`, 
      0.610570614047114`, 0.8476951993130497`, 1.`}\)], "Output"]
}, Open  ]],

Cell["In eine graphische Darstellung des Einheitsintervalls,", "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl1 = 
      Plot[0, {x, 0, 1}, Axes \[Rule] {True, False}, 
        PlotRange \[Rule] {{0, 1}, {\(-1\), 1}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[0 .29652 -3 -9 ]
[0 .29652 3 0 ]
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(0)] 0 .29652 0 1 Mshowa
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00123 .30902 L
.00236 .30902 L
.00365 .30902 L
.00488 .30902 L
.00601 .30902 L
.00706 .30902 L
.00821 .30902 L
.00942 .30902 L
.01065 .30902 L
.01196 .30902 L
.0132 .30902 L
.01434 .30902 L
.01566 .30902 L
.01641 .30902 L
.01711 .30902 L
.01839 .30902 L
.01975 .30902 L
.02043 .30902 L
.02115 .30902 L
.02245 .30902 L
.02317 .30902 L
.02384 .30902 L
.02458 .30902 L
.02537 .30902 L
.02605 .30902 L
.02679 .30902 L
.02814 .30902 L
.02945 .30902 L
.03067 .30902 L
.03184 .30902 L
.03295 .30902 L
.03416 .30902 L
.03547 .30902 L
.03676 .30902 L
.03813 .30902 L
.03929 .30902 L
.04057 .30902 L
.04131 .30902 L
.042 .30902 L
.04275 .30902 L
.04355 .30902 L
.0449 .30902 L
.04566 .30902 L
.04637 .30902 L
.0477 .30902 L
.04892 .30902 L
.04959 .30902 L
.05032 .30902 L
.05165 .30902 L
Mistroke
.05245 .30902 L
.05321 .30902 L
.05389 .30902 L
.05462 .30902 L
.05543 .30902 L
.05627 .30902 L
.057 .30902 L
.05779 .30902 L
.05854 .30902 L
.05921 .30902 L
.06 .30902 L
.06074 .30902 L
.06205 .30902 L
.0628 .30902 L
.06349 .30902 L
.06471 .30902 L
.06603 .30902 L
.06727 .30902 L
.06841 .30902 L
.06967 .30902 L
.07105 .30902 L
.07175 .30902 L
.07249 .30902 L
.07383 .30902 L
.07457 .30902 L
.07525 .30902 L
.076 .30902 L
.07679 .30902 L
.07812 .30902 L
.07888 .30902 L
.07959 .30902 L
.0809 .30902 L
.08211 .30902 L
.08349 .30902 L
.08481 .30902 L
.086 .30902 L
.08729 .30902 L
.0885 .30902 L
.08962 .30902 L
.09085 .30902 L
.0922 .30902 L
.09289 .30902 L
.09361 .30902 L
.09493 .30902 L
.09565 .30902 L
.09632 .30902 L
.09705 .30902 L
.09783 .30902 L
.09913 .30902 L
.09987 .30902 L
Mistroke
.10056 .30902 L
.10185 .30902 L
.10303 .30902 L
.10439 .30902 L
.10569 .30902 L
.10691 .30902 L
.10801 .30902 L
.10928 .30902 L
.11048 .30902 L
.1116 .30902 L
.11262 .30902 L
.11375 .30902 L
.11493 .30902 L
.11613 .30902 L
.11742 .30902 L
.11864 .30902 L
.11974 .30902 L
.12104 .30902 L
.12178 .30902 L
.12245 .30902 L
.1237 .30902 L
.12502 .30902 L
.12622 .30902 L
.12753 .30902 L
.12889 .30902 L
.13016 .30902 L
.13135 .30902 L
.13244 .30902 L
.13369 .30902 L
.13487 .30902 L
.13616 .30902 L
.13752 .30902 L
.13868 .30902 L
.13996 .30902 L
.14134 .30902 L
.14211 .30902 L
.14281 .30902 L
.14418 .30902 L
.14548 .30902 L
.14669 .30902 L
.14779 .30902 L
.14906 .30902 L
.15025 .30902 L
.15136 .30902 L
.15237 .30902 L
.15349 .30902 L
.15467 .30902 L
.15586 .30902 L
.15714 .30902 L
.15835 .30902 L
Mistroke
.15945 .30902 L
.16074 .30902 L
.16146 .30902 L
.16214 .30902 L
.16337 .30902 L
.16468 .30902 L
.16594 .30902 L
.16732 .30902 L
.16863 .30902 L
.16984 .30902 L
.17103 .30902 L
.17212 .30902 L
.17337 .30902 L
.17456 .30902 L
.17585 .30902 L
.17721 .30902 L
.17838 .30902 L
.17966 .30902 L
.18104 .30902 L
.18181 .30902 L
.18251 .30902 L
.18388 .30902 L
.18518 .30902 L
.18628 .30902 L
.1875 .30902 L
.18877 .30902 L
.18996 .30902 L
.19107 .30902 L
.19209 .30902 L
.19321 .30902 L
.19438 .30902 L
.19558 .30902 L
.19686 .30902 L
.19807 .30902 L
.19916 .30902 L
.20045 .30902 L
.20118 .30902 L
.20185 .30902 L
.20309 .30902 L
.20439 .30902 L
.20566 .30902 L
.20705 .30902 L
.20835 .30902 L
.20957 .30902 L
.21077 .30902 L
.21186 .30902 L
.21311 .30902 L
.2143 .30902 L
.21559 .30902 L
.21696 .30902 L
Mistroke
.21813 .30902 L
.21941 .30902 L
.22079 .30902 L
.22157 .30902 L
.22227 .30902 L
.22364 .30902 L
.22494 .30902 L
.22604 .30902 L
.22726 .30902 L
.22853 .30902 L
.22973 .30902 L
.23084 .30902 L
.23186 .30902 L
.23297 .30902 L
.23415 .30902 L
.23535 .30902 L
.23663 .30902 L
.23784 .30902 L
.23893 .30902 L
.24023 .30902 L
.24095 .30902 L
.24163 .30902 L
.24286 .30902 L
.24416 .30902 L
.24544 .30902 L
.24683 .30902 L
.24814 .30902 L
.24935 .30902 L
.25044 .30902 L
.25165 .30902 L
.25291 .30902 L
.25409 .30902 L
.25539 .30902 L
.25676 .30902 L
.25793 .30902 L
.25922 .30902 L
.2606 .30902 L
.26137 .30902 L
.26208 .30902 L
.26345 .30902 L
.26475 .30902 L
.26586 .30902 L
.26708 .30902 L
.26835 .30902 L
.26954 .30902 L
.27066 .30902 L
.27168 .30902 L
.27286 .30902 L
.27397 .30902 L
.27518 .30902 L
Mistroke
.27646 .30902 L
.27767 .30902 L
.27876 .30902 L
.28005 .30902 L
.28078 .30902 L
.28145 .30902 L
.28268 .30902 L
.28399 .30902 L
.28527 .30902 L
.28599 .30902 L
.28666 .30902 L
.28789 .30902 L
.28919 .30902 L
.29036 .30902 L
.29145 .30902 L
.29265 .30902 L
.29394 .30902 L
.29524 .30902 L
.29597 .30902 L
.29665 .30902 L
.29803 .30902 L
.29881 .30902 L
.29951 .30902 L
.30077 .30902 L
.30213 .30902 L
.30342 .30902 L
.30461 .30902 L
.30572 .30902 L
.30691 .30902 L
.30804 .30902 L
.30907 .30902 L
.31027 .30902 L
.31158 .30902 L
.31282 .30902 L
.31396 .30902 L
.31526 .30902 L
.31648 .30902 L
.31758 .30902 L
.31876 .30902 L
.32005 .30902 L
.32142 .30902 L
.32259 .30902 L
.32386 .30902 L
.32524 .30902 L
.32651 .30902 L
.32718 .30902 L
.32791 .30902 L
.32867 .30902 L
.32939 .30902 L
.3307 .30902 L
Mistroke
.3319 .30902 L
.33329 .30902 L
.33461 .30902 L
.33578 .30902 L
.33704 .30902 L
.33822 .30902 L
.33929 .30902 L
.34055 .30902 L
.34192 .30902 L
.34321 .30902 L
.3444 .30902 L
.34567 .30902 L
.34703 .30902 L
.34831 .30902 L
.34949 .30902 L
.35086 .30902 L
.35164 .30902 L
.35236 .30902 L
.35368 .30902 L
.35434 .30902 L
.35508 .30902 L
.35579 .30902 L
.35654 .30902 L
.35788 .30902 L
.35863 .30902 L
.35932 .30902 L
.36009 .30902 L
.3609 .30902 L
.36161 .30902 L
.36238 .30902 L
.3631 .30902 L
.36377 .30902 L
.36503 .30902 L
.36637 .30902 L
.36764 .30902 L
.36902 .30902 L
.37033 .30902 L
.37154 .30902 L
.37274 .30902 L
.37383 .30902 L
.37509 .30902 L
.37627 .30902 L
.37756 .30902 L
.37893 .30902 L
.3801 .30902 L
.38138 .30902 L
.38276 .30902 L
.38353 .30902 L
.38424 .30902 L
.38561 .30902 L
Mistroke
.38691 .30902 L
.38801 .30902 L
.38923 .30902 L
.3905 .30902 L
.39169 .30902 L
.3928 .30902 L
.39382 .30902 L
.39494 .30902 L
.39612 .30902 L
.39732 .30902 L
.3986 .30902 L
.3998 .30902 L
.4009 .30902 L
.40219 .30902 L
.40292 .30902 L
.40359 .30902 L
.40482 .30902 L
.40613 .30902 L
.4074 .30902 L
.40879 .30902 L
.4101 .30902 L
.41132 .30902 L
.41252 .30902 L
.41361 .30902 L
.41487 .30902 L
.41605 .30902 L
.41735 .30902 L
.41872 .30902 L
.41989 .30902 L
.42117 .30902 L
.42256 .30902 L
.42333 .30902 L
.42404 .30902 L
.42541 .30902 L
.4267 .30902 L
.42781 .30902 L
.42903 .30902 L
.43031 .30902 L
.4315 .30902 L
.43261 .30902 L
.43363 .30902 L
.43481 .30902 L
.43593 .30902 L
.43713 .30902 L
.43841 .30902 L
.43962 .30902 L
.44071 .30902 L
.44201 .30902 L
.44273 .30902 L
.4434 .30902 L
Mistroke
.44464 .30902 L
.44594 .30902 L
.44722 .30902 L
.44794 .30902 L
.44861 .30902 L
.44984 .30902 L
.45114 .30902 L
.45231 .30902 L
.4534 .30902 L
.4546 .30902 L
.45589 .30902 L
.45718 .30902 L
.45792 .30902 L
.4586 .30902 L
.45998 .30902 L
.46075 .30902 L
.46145 .30902 L
.46271 .30902 L
.46408 .30902 L
.46537 .30902 L
.46656 .30902 L
.46766 .30902 L
.46886 .30902 L
.46998 .30902 L
.47101 .30902 L
.47221 .30902 L
.47352 .30902 L
.47476 .30902 L
.4759 .30902 L
.4772 .30902 L
.47842 .30902 L
.47952 .30902 L
.4807 .30902 L
.48199 .30902 L
.48336 .30902 L
.48453 .30902 L
.4858 .30902 L
.48718 .30902 L
.48845 .30902 L
.48911 .30902 L
.48984 .30902 L
.49061 .30902 L
.49132 .30902 L
.49264 .30902 L
.49384 .30902 L
.49516 .30902 L
.49655 .30902 L
.49772 .30902 L
.49897 .30902 L
.50015 .30902 L
Mistroke
.50122 .30902 L
.50248 .30902 L
.50385 .30902 L
.50514 .30902 L
.50633 .30902 L
.5076 .30902 L
.50896 .30902 L
.51024 .30902 L
.51142 .30902 L
.51279 .30902 L
.51357 .30902 L
.51429 .30902 L
.5156 .30902 L
.51627 .30902 L
.51701 .30902 L
.51772 .30902 L
.51847 .30902 L
.51981 .30902 L
.52055 .30902 L
.52125 .30902 L
.52201 .30902 L
.52283 .30902 L
.52354 .30902 L
.5243 .30902 L
.52503 .30902 L
.52569 .30902 L
.52696 .30902 L
.5283 .30902 L
.52957 .30902 L
.53095 .30902 L
.53225 .30902 L
.53347 .30902 L
.53467 .30902 L
.53575 .30902 L
.53701 .30902 L
.53819 .30902 L
.53948 .30902 L
.54085 .30902 L
.54202 .30902 L
.5433 .30902 L
.54468 .30902 L
.54545 .30902 L
.54616 .30902 L
.54753 .30902 L
.54882 .30902 L
.54993 .30902 L
.55114 .30902 L
.55241 .30902 L
.55361 .30902 L
.55472 .30902 L
Mistroke
.55574 .30902 L
.55685 .30902 L
.55803 .30902 L
.55923 .30902 L
.56051 .30902 L
.56172 .30902 L
.56281 .30902 L
.5641 .30902 L
.56483 .30902 L
.5655 .30902 L
.56674 .30902 L
.56804 .30902 L
.56932 .30902 L
.5707 .30902 L
.57201 .30902 L
.57323 .30902 L
.57443 .30902 L
.57552 .30902 L
.57678 .30902 L
.57796 .30902 L
.57926 .30902 L
.58063 .30902 L
.5818 .30902 L
.58308 .30902 L
.58446 .30902 L
.58524 .30902 L
.58594 .30902 L
.58731 .30902 L
.58861 .30902 L
.58971 .30902 L
.59093 .30902 L
.59221 .30902 L
.5934 .30902 L
.59451 .30902 L
.59553 .30902 L
.59671 .30902 L
.59783 .30902 L
.59903 .30902 L
.60031 .30902 L
.60152 .30902 L
.60261 .30902 L
.60391 .30902 L
.60463 .30902 L
.6053 .30902 L
.60654 .30902 L
.60784 .30902 L
.60912 .30902 L
.60984 .30902 L
.61051 .30902 L
.61174 .30902 L
Mistroke
.61304 .30902 L
.6142 .30902 L
.61529 .30902 L
.61649 .30902 L
.61778 .30902 L
.61908 .30902 L
.61981 .30902 L
.62049 .30902 L
.62187 .30902 L
.62264 .30902 L
.62335 .30902 L
.6246 .30902 L
.62597 .30902 L
.62726 .30902 L
.62845 .30902 L
.62955 .30902 L
.63075 .30902 L
.63187 .30902 L
.6329 .30902 L
.6341 .30902 L
.63541 .30902 L
.63665 .30902 L
.63779 .30902 L
.63909 .30902 L
.64031 .30902 L
.6414 .30902 L
.64259 .30902 L
.64388 .30902 L
.64525 .30902 L
.64641 .30902 L
.64769 .30902 L
.64907 .30902 L
.65034 .30902 L
.651 .30902 L
.65173 .30902 L
.65249 .30902 L
.65321 .30902 L
.65452 .30902 L
.65572 .30902 L
.65704 .30902 L
.65843 .30902 L
.6596 .30902 L
.66085 .30902 L
.66203 .30902 L
.6631 .30902 L
.66436 .30902 L
.66573 .30902 L
.66702 .30902 L
.66821 .30902 L
.66947 .30902 L
Mistroke
.67083 .30902 L
.67212 .30902 L
.67329 .30902 L
.67467 .30902 L
.67544 .30902 L
.67616 .30902 L
.67748 .30902 L
.67815 .30902 L
.67888 .30902 L
.67959 .30902 L
.68034 .30902 L
.68168 .30902 L
.68243 .30902 L
.68312 .30902 L
.68389 .30902 L
.6847 .30902 L
.68541 .30902 L
.68618 .30902 L
.6869 .30902 L
.68757 .30902 L
.68883 .30902 L
.69018 .30902 L
.69144 .30902 L
.69282 .30902 L
.69413 .30902 L
.69534 .30902 L
.69654 .30902 L
.69762 .30902 L
.69888 .30902 L
.70006 .30902 L
.70135 .30902 L
.70272 .30902 L
.70388 .30902 L
.70517 .30902 L
.70654 .30902 L
.70732 .30902 L
.70802 .30902 L
.70939 .30902 L
.71069 .30902 L
.71179 .30902 L
.71301 .30902 L
.71428 .30902 L
.71547 .30902 L
.71658 .30902 L
.7176 .30902 L
.71872 .30902 L
.71989 .30902 L
.72109 .30902 L
.72237 .30902 L
.72358 .30902 L
Mistroke
.72468 .30902 L
.72597 .30902 L
.72669 .30902 L
.72737 .30902 L
.7286 .30902 L
.72991 .30902 L
.73118 .30902 L
.73256 .30902 L
.73387 .30902 L
.73508 .30902 L
.73629 .30902 L
.73738 .30902 L
.73863 .30902 L
.73982 .30902 L
.74111 .30902 L
.74248 .30902 L
.74365 .30902 L
.74493 .30902 L
.74631 .30902 L
.74709 .30902 L
.74779 .30902 L
.74916 .30902 L
.75046 .30902 L
.75157 .30902 L
.75279 .30902 L
.75406 .30902 L
.75525 .30902 L
.75636 .30902 L
.75738 .30902 L
.7585 .30902 L
.75968 .30902 L
.76088 .30902 L
.76216 .30902 L
.76337 .30902 L
.76446 .30902 L
.76575 .30902 L
.76648 .30902 L
.76715 .30902 L
.76839 .30902 L
.76969 .30902 L
.77097 .30902 L
.77169 .30902 L
.77236 .30902 L
.77358 .30902 L
.77489 .30902 L
.77605 .30902 L
.77714 .30902 L
.77834 .30902 L
.77963 .30902 L
.78092 .30902 L
Mistroke
.78165 .30902 L
.78233 .30902 L
.78371 .30902 L
.78448 .30902 L
.78519 .30902 L
.78644 .30902 L
.78781 .30902 L
.7891 .30902 L
.79029 .30902 L
.79139 .30902 L
.79258 .30902 L
.79371 .30902 L
.79473 .30902 L
.79593 .30902 L
.79724 .30902 L
.79848 .30902 L
.79963 .30902 L
.80093 .30902 L
.80214 .30902 L
.80324 .30902 L
.80442 .30902 L
.80572 .30902 L
.80708 .30902 L
.80825 .30902 L
.80953 .30902 L
.8109 .30902 L
.81217 .30902 L
.81283 .30902 L
.81356 .30902 L
.81432 .30902 L
.81504 .30902 L
.81635 .30902 L
.81755 .30902 L
.81887 .30902 L
.82026 .30902 L
.82143 .30902 L
.82268 .30902 L
.82386 .30902 L
.82493 .30902 L
.82619 .30902 L
.82755 .30902 L
.82884 .30902 L
.83003 .30902 L
.8313 .30902 L
.83266 .30902 L
.83394 .30902 L
.83512 .30902 L
.83649 .30902 L
.83727 .30902 L
.83798 .30902 L
Mistroke
.8393 .30902 L
.84004 .30902 L
.84071 .30902 L
.84142 .30902 L
.84216 .30902 L
.8435 .30902 L
.84425 .30902 L
.84495 .30902 L
.84571 .30902 L
.84653 .30902 L
.84723 .30902 L
.848 .30902 L
.84872 .30902 L
.84939 .30902 L
.85066 .30902 L
.852 .30902 L
.85326 .30902 L
.85464 .30902 L
.85595 .30902 L
.85716 .30902 L
.85835 .30902 L
.85944 .30902 L
.86069 .30902 L
.86188 .30902 L
.86317 .30902 L
.86453 .30902 L
.8657 .30902 L
.86698 .30902 L
.86836 .30902 L
.86913 .30902 L
.86984 .30902 L
.87121 .30902 L
.8725 .30902 L
.8736 .30902 L
.87482 .30902 L
.87609 .30902 L
.87728 .30902 L
.87839 .30902 L
.87941 .30902 L
.88053 .30902 L
.8817 .30902 L
.8829 .30902 L
.88418 .30902 L
.88539 .30902 L
.88649 .30902 L
.88778 .30902 L
.8885 .30902 L
.88918 .30902 L
.89041 .30902 L
.89172 .30902 L
Mistroke
.89299 .30902 L
.89437 .30902 L
.89568 .30902 L
.89689 .30902 L
.89809 .30902 L
.89918 .30902 L
.90044 .30902 L
.90162 .30902 L
.90292 .30902 L
.90428 .30902 L
.90545 .30902 L
.90673 .30902 L
.90812 .30902 L
.90889 .30902 L
.90959 .30902 L
.91096 .30902 L
.91226 .30902 L
.91337 .30902 L
.91458 .30902 L
.91586 .30902 L
.91705 .30902 L
.91816 .30902 L
.91918 .30902 L
.9203 .30902 L
.92148 .30902 L
.92268 .30902 L
.92396 .30902 L
.92516 .30902 L
.92626 .30902 L
.92755 .30902 L
.92828 .30902 L
.92895 .30902 L
.93018 .30902 L
.93149 .30902 L
.93276 .30902 L
.93348 .30902 L
.93415 .30902 L
.93538 .30902 L
.93668 .30902 L
.93784 .30902 L
.93893 .30902 L
.94013 .30902 L
.94142 .30902 L
.94271 .30902 L
.94344 .30902 L
.94412 .30902 L
.9455 .30902 L
.94627 .30902 L
.94697 .30902 L
.94823 .30902 L
Mistroke
.9496 .30902 L
.95089 .30902 L
.95207 .30902 L
.95318 .30902 L
.95437 .30902 L
.95549 .30902 L
.95652 .30902 L
.95772 .30902 L
.95903 .30902 L
.96027 .30902 L
.96141 .30902 L
.96271 .30902 L
.96393 .30902 L
.96502 .30902 L
.96621 .30902 L
.9675 .30902 L
.96887 .30902 L
.97003 .30902 L
.97131 .30902 L
.97224 .30902 L
.9731 .30902 L
.97404 .30902 L
.97503 .30902 L
.9759 .30902 L
.97671 .30902 L
.9776 .30902 L
.97856 .30902 L
.97936 .30902 L
.98024 .30902 L
.98115 .30902 L
.982 .30902 L
.9828 .30902 L
.98353 .30902 L
.98437 .30902 L
.98516 .30902 L
.98602 .30902 L
.98696 .30902 L
.98795 .30902 L
.98887 .30902 L
.98973 .30902 L
.99051 .30902 L
.99142 .30902 L
.99228 .30902 L
.99321 .30902 L
.9942 .30902 L
.99513 .30902 L
.99598 .30902 L
.99697 .30902 L
.99805 .30902 L
.99907 .30902 L
Mistroke
1 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000P3oool200000300oooo0P0000040?ooo`8000000`3oool4000002T0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002X0
oooo0P0000040?ooo`800000103oool200000300oooo1@0000010?ooo`0000D0oooo0000003oool0
oooo0000000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:@3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000a0?ooo`030000003oool0
oooo0040oooo00001@3oool000000?ooo`3oool0000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:@3oool010000000oooo0?ooo`000009
0?ooo`800000<P3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0?ooo`010?ooo`000P3oool200000300oooo0P00000:0?ooo`800000:P3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002T0oooo0P00000:0?ooo`800000<@3oool2
000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo00030?ooool000006`0000030?ooo`000`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0040oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0106813, -1.01885, \
0.00355875, 0.0115164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["lassen sich nun diese Intervallgrenzen einzeichnen:", "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(Do[{\[IndentingNewLine]\(plX[k] = 
            ListPlot[{{cumDist[\([k]\)], 0}, {cumDist[\([k]\)], 0.2}}, 
              PlotJoined \[Rule] True, 
              PlotStyle \[Rule] {AbsoluteThickness[3], RGBColor[0, 0, 1]}, 
              DisplayFunction \[Rule] Identity];\)\[IndentingNewLine]}, {k, 
        1, Length[cumDist]}]\)], "Input"],

Cell[TextData[{
  "Die ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife ist ein zentrales Element der Programmierung in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Die erste geschweifte Klammer enth\[ADoubleDot]lt die Abfolge von \
Befehlen, die in jedem Schleifenschritt ausgef\[UDoubleDot]hrt werden. In \
unserem Beispiel enth\[ADoubleDot]lt sie nur einen einzigen Befehl. Die \
zweite Klammer legt die Schleifenvariable (hier: ",
  StyleBox["k",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") und ihren Anfangs",
  StyleBox[" ",
    FontFamily->"Times-Roman~26",
    FontSize->10],
  "und Endwert in der Schleife fest. Es ist deutlich zu sehen, dass in den \
Befehlen (erste Klammer) diese Variable verwendet werden kann."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pl00 = 
        Show[Flatten[{pl1, Table[plX[k], {k, 1, Length[cumDist]}]}], 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[0 .29652 -3 -9 ]
[0 .29652 3 0 ]
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(0)] 0 .29652 0 1 Mshowa
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00123 .30902 L
.00236 .30902 L
.00365 .30902 L
.00488 .30902 L
.00601 .30902 L
.00706 .30902 L
.00821 .30902 L
.00942 .30902 L
.01065 .30902 L
.01196 .30902 L
.0132 .30902 L
.01434 .30902 L
.01566 .30902 L
.01641 .30902 L
.01711 .30902 L
.01839 .30902 L
.01975 .30902 L
.02043 .30902 L
.02115 .30902 L
.02245 .30902 L
.02317 .30902 L
.02384 .30902 L
.02458 .30902 L
.02537 .30902 L
.02605 .30902 L
.02679 .30902 L
.02814 .30902 L
.02945 .30902 L
.03067 .30902 L
.03184 .30902 L
.03295 .30902 L
.03416 .30902 L
.03547 .30902 L
.03676 .30902 L
.03813 .30902 L
.03929 .30902 L
.04057 .30902 L
.04131 .30902 L
.042 .30902 L
.04275 .30902 L
.04355 .30902 L
.0449 .30902 L
.04566 .30902 L
.04637 .30902 L
.0477 .30902 L
.04892 .30902 L
.04959 .30902 L
.05032 .30902 L
.05165 .30902 L
Mistroke
.05245 .30902 L
.05321 .30902 L
.05389 .30902 L
.05462 .30902 L
.05543 .30902 L
.05627 .30902 L
.057 .30902 L
.05779 .30902 L
.05854 .30902 L
.05921 .30902 L
.06 .30902 L
.06074 .30902 L
.06205 .30902 L
.0628 .30902 L
.06349 .30902 L
.06471 .30902 L
.06603 .30902 L
.06727 .30902 L
.06841 .30902 L
.06967 .30902 L
.07105 .30902 L
.07175 .30902 L
.07249 .30902 L
.07383 .30902 L
.07457 .30902 L
.07525 .30902 L
.076 .30902 L
.07679 .30902 L
.07812 .30902 L
.07888 .30902 L
.07959 .30902 L
.0809 .30902 L
.08211 .30902 L
.08349 .30902 L
.08481 .30902 L
.086 .30902 L
.08729 .30902 L
.0885 .30902 L
.08962 .30902 L
.09085 .30902 L
.0922 .30902 L
.09289 .30902 L
.09361 .30902 L
.09493 .30902 L
.09565 .30902 L
.09632 .30902 L
.09705 .30902 L
.09783 .30902 L
.09913 .30902 L
.09987 .30902 L
Mistroke
.10056 .30902 L
.10185 .30902 L
.10303 .30902 L
.10439 .30902 L
.10569 .30902 L
.10691 .30902 L
.10801 .30902 L
.10928 .30902 L
.11048 .30902 L
.1116 .30902 L
.11262 .30902 L
.11375 .30902 L
.11493 .30902 L
.11613 .30902 L
.11742 .30902 L
.11864 .30902 L
.11974 .30902 L
.12104 .30902 L
.12178 .30902 L
.12245 .30902 L
.1237 .30902 L
.12502 .30902 L
.12622 .30902 L
.12753 .30902 L
.12889 .30902 L
.13016 .30902 L
.13135 .30902 L
.13244 .30902 L
.13369 .30902 L
.13487 .30902 L
.13616 .30902 L
.13752 .30902 L
.13868 .30902 L
.13996 .30902 L
.14134 .30902 L
.14211 .30902 L
.14281 .30902 L
.14418 .30902 L
.14548 .30902 L
.14669 .30902 L
.14779 .30902 L
.14906 .30902 L
.15025 .30902 L
.15136 .30902 L
.15237 .30902 L
.15349 .30902 L
.15467 .30902 L
.15586 .30902 L
.15714 .30902 L
.15835 .30902 L
Mistroke
.15945 .30902 L
.16074 .30902 L
.16146 .30902 L
.16214 .30902 L
.16337 .30902 L
.16468 .30902 L
.16594 .30902 L
.16732 .30902 L
.16863 .30902 L
.16984 .30902 L
.17103 .30902 L
.17212 .30902 L
.17337 .30902 L
.17456 .30902 L
.17585 .30902 L
.17721 .30902 L
.17838 .30902 L
.17966 .30902 L
.18104 .30902 L
.18181 .30902 L
.18251 .30902 L
.18388 .30902 L
.18518 .30902 L
.18628 .30902 L
.1875 .30902 L
.18877 .30902 L
.18996 .30902 L
.19107 .30902 L
.19209 .30902 L
.19321 .30902 L
.19438 .30902 L
.19558 .30902 L
.19686 .30902 L
.19807 .30902 L
.19916 .30902 L
.20045 .30902 L
.20118 .30902 L
.20185 .30902 L
.20309 .30902 L
.20439 .30902 L
.20566 .30902 L
.20705 .30902 L
.20835 .30902 L
.20957 .30902 L
.21077 .30902 L
.21186 .30902 L
.21311 .30902 L
.2143 .30902 L
.21559 .30902 L
.21696 .30902 L
Mistroke
.21813 .30902 L
.21941 .30902 L
.22079 .30902 L
.22157 .30902 L
.22227 .30902 L
.22364 .30902 L
.22494 .30902 L
.22604 .30902 L
.22726 .30902 L
.22853 .30902 L
.22973 .30902 L
.23084 .30902 L
.23186 .30902 L
.23297 .30902 L
.23415 .30902 L
.23535 .30902 L
.23663 .30902 L
.23784 .30902 L
.23893 .30902 L
.24023 .30902 L
.24095 .30902 L
.24163 .30902 L
.24286 .30902 L
.24416 .30902 L
.24544 .30902 L
.24683 .30902 L
.24814 .30902 L
.24935 .30902 L
.25044 .30902 L
.25165 .30902 L
.25291 .30902 L
.25409 .30902 L
.25539 .30902 L
.25676 .30902 L
.25793 .30902 L
.25922 .30902 L
.2606 .30902 L
.26137 .30902 L
.26208 .30902 L
.26345 .30902 L
.26475 .30902 L
.26586 .30902 L
.26708 .30902 L
.26835 .30902 L
.26954 .30902 L
.27066 .30902 L
.27168 .30902 L
.27286 .30902 L
.27397 .30902 L
.27518 .30902 L
Mistroke
.27646 .30902 L
.27767 .30902 L
.27876 .30902 L
.28005 .30902 L
.28078 .30902 L
.28145 .30902 L
.28268 .30902 L
.28399 .30902 L
.28527 .30902 L
.28599 .30902 L
.28666 .30902 L
.28789 .30902 L
.28919 .30902 L
.29036 .30902 L
.29145 .30902 L
.29265 .30902 L
.29394 .30902 L
.29524 .30902 L
.29597 .30902 L
.29665 .30902 L
.29803 .30902 L
.29881 .30902 L
.29951 .30902 L
.30077 .30902 L
.30213 .30902 L
.30342 .30902 L
.30461 .30902 L
.30572 .30902 L
.30691 .30902 L
.30804 .30902 L
.30907 .30902 L
.31027 .30902 L
.31158 .30902 L
.31282 .30902 L
.31396 .30902 L
.31526 .30902 L
.31648 .30902 L
.31758 .30902 L
.31876 .30902 L
.32005 .30902 L
.32142 .30902 L
.32259 .30902 L
.32386 .30902 L
.32524 .30902 L
.32651 .30902 L
.32718 .30902 L
.32791 .30902 L
.32867 .30902 L
.32939 .30902 L
.3307 .30902 L
Mistroke
.3319 .30902 L
.33329 .30902 L
.33461 .30902 L
.33578 .30902 L
.33704 .30902 L
.33822 .30902 L
.33929 .30902 L
.34055 .30902 L
.34192 .30902 L
.34321 .30902 L
.3444 .30902 L
.34567 .30902 L
.34703 .30902 L
.34831 .30902 L
.34949 .30902 L
.35086 .30902 L
.35164 .30902 L
.35236 .30902 L
.35368 .30902 L
.35434 .30902 L
.35508 .30902 L
.35579 .30902 L
.35654 .30902 L
.35788 .30902 L
.35863 .30902 L
.35932 .30902 L
.36009 .30902 L
.3609 .30902 L
.36161 .30902 L
.36238 .30902 L
.3631 .30902 L
.36377 .30902 L
.36503 .30902 L
.36637 .30902 L
.36764 .30902 L
.36902 .30902 L
.37033 .30902 L
.37154 .30902 L
.37274 .30902 L
.37383 .30902 L
.37509 .30902 L
.37627 .30902 L
.37756 .30902 L
.37893 .30902 L
.3801 .30902 L
.38138 .30902 L
.38276 .30902 L
.38353 .30902 L
.38424 .30902 L
.38561 .30902 L
Mistroke
.38691 .30902 L
.38801 .30902 L
.38923 .30902 L
.3905 .30902 L
.39169 .30902 L
.3928 .30902 L
.39382 .30902 L
.39494 .30902 L
.39612 .30902 L
.39732 .30902 L
.3986 .30902 L
.3998 .30902 L
.4009 .30902 L
.40219 .30902 L
.40292 .30902 L
.40359 .30902 L
.40482 .30902 L
.40613 .30902 L
.4074 .30902 L
.40879 .30902 L
.4101 .30902 L
.41132 .30902 L
.41252 .30902 L
.41361 .30902 L
.41487 .30902 L
.41605 .30902 L
.41735 .30902 L
.41872 .30902 L
.41989 .30902 L
.42117 .30902 L
.42256 .30902 L
.42333 .30902 L
.42404 .30902 L
.42541 .30902 L
.4267 .30902 L
.42781 .30902 L
.42903 .30902 L
.43031 .30902 L
.4315 .30902 L
.43261 .30902 L
.43363 .30902 L
.43481 .30902 L
.43593 .30902 L
.43713 .30902 L
.43841 .30902 L
.43962 .30902 L
.44071 .30902 L
.44201 .30902 L
.44273 .30902 L
.4434 .30902 L
Mistroke
.44464 .30902 L
.44594 .30902 L
.44722 .30902 L
.44794 .30902 L
.44861 .30902 L
.44984 .30902 L
.45114 .30902 L
.45231 .30902 L
.4534 .30902 L
.4546 .30902 L
.45589 .30902 L
.45718 .30902 L
.45792 .30902 L
.4586 .30902 L
.45998 .30902 L
.46075 .30902 L
.46145 .30902 L
.46271 .30902 L
.46408 .30902 L
.46537 .30902 L
.46656 .30902 L
.46766 .30902 L
.46886 .30902 L
.46998 .30902 L
.47101 .30902 L
.47221 .30902 L
.47352 .30902 L
.47476 .30902 L
.4759 .30902 L
.4772 .30902 L
.47842 .30902 L
.47952 .30902 L
.4807 .30902 L
.48199 .30902 L
.48336 .30902 L
.48453 .30902 L
.4858 .30902 L
.48718 .30902 L
.48845 .30902 L
.48911 .30902 L
.48984 .30902 L
.49061 .30902 L
.49132 .30902 L
.49264 .30902 L
.49384 .30902 L
.49516 .30902 L
.49655 .30902 L
.49772 .30902 L
.49897 .30902 L
.50015 .30902 L
Mistroke
.50122 .30902 L
.50248 .30902 L
.50385 .30902 L
.50514 .30902 L
.50633 .30902 L
.5076 .30902 L
.50896 .30902 L
.51024 .30902 L
.51142 .30902 L
.51279 .30902 L
.51357 .30902 L
.51429 .30902 L
.5156 .30902 L
.51627 .30902 L
.51701 .30902 L
.51772 .30902 L
.51847 .30902 L
.51981 .30902 L
.52055 .30902 L
.52125 .30902 L
.52201 .30902 L
.52283 .30902 L
.52354 .30902 L
.5243 .30902 L
.52503 .30902 L
.52569 .30902 L
.52696 .30902 L
.5283 .30902 L
.52957 .30902 L
.53095 .30902 L
.53225 .30902 L
.53347 .30902 L
.53467 .30902 L
.53575 .30902 L
.53701 .30902 L
.53819 .30902 L
.53948 .30902 L
.54085 .30902 L
.54202 .30902 L
.5433 .30902 L
.54468 .30902 L
.54545 .30902 L
.54616 .30902 L
.54753 .30902 L
.54882 .30902 L
.54993 .30902 L
.55114 .30902 L
.55241 .30902 L
.55361 .30902 L
.55472 .30902 L
Mistroke
.55574 .30902 L
.55685 .30902 L
.55803 .30902 L
.55923 .30902 L
.56051 .30902 L
.56172 .30902 L
.56281 .30902 L
.5641 .30902 L
.56483 .30902 L
.5655 .30902 L
.56674 .30902 L
.56804 .30902 L
.56932 .30902 L
.5707 .30902 L
.57201 .30902 L
.57323 .30902 L
.57443 .30902 L
.57552 .30902 L
.57678 .30902 L
.57796 .30902 L
.57926 .30902 L
.58063 .30902 L
.5818 .30902 L
.58308 .30902 L
.58446 .30902 L
.58524 .30902 L
.58594 .30902 L
.58731 .30902 L
.58861 .30902 L
.58971 .30902 L
.59093 .30902 L
.59221 .30902 L
.5934 .30902 L
.59451 .30902 L
.59553 .30902 L
.59671 .30902 L
.59783 .30902 L
.59903 .30902 L
.60031 .30902 L
.60152 .30902 L
.60261 .30902 L
.60391 .30902 L
.60463 .30902 L
.6053 .30902 L
.60654 .30902 L
.60784 .30902 L
.60912 .30902 L
.60984 .30902 L
.61051 .30902 L
.61174 .30902 L
Mistroke
.61304 .30902 L
.6142 .30902 L
.61529 .30902 L
.61649 .30902 L
.61778 .30902 L
.61908 .30902 L
.61981 .30902 L
.62049 .30902 L
.62187 .30902 L
.62264 .30902 L
.62335 .30902 L
.6246 .30902 L
.62597 .30902 L
.62726 .30902 L
.62845 .30902 L
.62955 .30902 L
.63075 .30902 L
.63187 .30902 L
.6329 .30902 L
.6341 .30902 L
.63541 .30902 L
.63665 .30902 L
.63779 .30902 L
.63909 .30902 L
.64031 .30902 L
.6414 .30902 L
.64259 .30902 L
.64388 .30902 L
.64525 .30902 L
.64641 .30902 L
.64769 .30902 L
.64907 .30902 L
.65034 .30902 L
.651 .30902 L
.65173 .30902 L
.65249 .30902 L
.65321 .30902 L
.65452 .30902 L
.65572 .30902 L
.65704 .30902 L
.65843 .30902 L
.6596 .30902 L
.66085 .30902 L
.66203 .30902 L
.6631 .30902 L
.66436 .30902 L
.66573 .30902 L
.66702 .30902 L
.66821 .30902 L
.66947 .30902 L
Mistroke
.67083 .30902 L
.67212 .30902 L
.67329 .30902 L
.67467 .30902 L
.67544 .30902 L
.67616 .30902 L
.67748 .30902 L
.67815 .30902 L
.67888 .30902 L
.67959 .30902 L
.68034 .30902 L
.68168 .30902 L
.68243 .30902 L
.68312 .30902 L
.68389 .30902 L
.6847 .30902 L
.68541 .30902 L
.68618 .30902 L
.6869 .30902 L
.68757 .30902 L
.68883 .30902 L
.69018 .30902 L
.69144 .30902 L
.69282 .30902 L
.69413 .30902 L
.69534 .30902 L
.69654 .30902 L
.69762 .30902 L
.69888 .30902 L
.70006 .30902 L
.70135 .30902 L
.70272 .30902 L
.70388 .30902 L
.70517 .30902 L
.70654 .30902 L
.70732 .30902 L
.70802 .30902 L
.70939 .30902 L
.71069 .30902 L
.71179 .30902 L
.71301 .30902 L
.71428 .30902 L
.71547 .30902 L
.71658 .30902 L
.7176 .30902 L
.71872 .30902 L
.71989 .30902 L
.72109 .30902 L
.72237 .30902 L
.72358 .30902 L
Mistroke
.72468 .30902 L
.72597 .30902 L
.72669 .30902 L
.72737 .30902 L
.7286 .30902 L
.72991 .30902 L
.73118 .30902 L
.73256 .30902 L
.73387 .30902 L
.73508 .30902 L
.73629 .30902 L
.73738 .30902 L
.73863 .30902 L
.73982 .30902 L
.74111 .30902 L
.74248 .30902 L
.74365 .30902 L
.74493 .30902 L
.74631 .30902 L
.74709 .30902 L
.74779 .30902 L
.74916 .30902 L
.75046 .30902 L
.75157 .30902 L
.75279 .30902 L
.75406 .30902 L
.75525 .30902 L
.75636 .30902 L
.75738 .30902 L
.7585 .30902 L
.75968 .30902 L
.76088 .30902 L
.76216 .30902 L
.76337 .30902 L
.76446 .30902 L
.76575 .30902 L
.76648 .30902 L
.76715 .30902 L
.76839 .30902 L
.76969 .30902 L
.77097 .30902 L
.77169 .30902 L
.77236 .30902 L
.77358 .30902 L
.77489 .30902 L
.77605 .30902 L
.77714 .30902 L
.77834 .30902 L
.77963 .30902 L
.78092 .30902 L
Mistroke
.78165 .30902 L
.78233 .30902 L
.78371 .30902 L
.78448 .30902 L
.78519 .30902 L
.78644 .30902 L
.78781 .30902 L
.7891 .30902 L
.79029 .30902 L
.79139 .30902 L
.79258 .30902 L
.79371 .30902 L
.79473 .30902 L
.79593 .30902 L
.79724 .30902 L
.79848 .30902 L
.79963 .30902 L
.80093 .30902 L
.80214 .30902 L
.80324 .30902 L
.80442 .30902 L
.80572 .30902 L
.80708 .30902 L
.80825 .30902 L
.80953 .30902 L
.8109 .30902 L
.81217 .30902 L
.81283 .30902 L
.81356 .30902 L
.81432 .30902 L
.81504 .30902 L
.81635 .30902 L
.81755 .30902 L
.81887 .30902 L
.82026 .30902 L
.82143 .30902 L
.82268 .30902 L
.82386 .30902 L
.82493 .30902 L
.82619 .30902 L
.82755 .30902 L
.82884 .30902 L
.83003 .30902 L
.8313 .30902 L
.83266 .30902 L
.83394 .30902 L
.83512 .30902 L
.83649 .30902 L
.83727 .30902 L
.83798 .30902 L
Mistroke
.8393 .30902 L
.84004 .30902 L
.84071 .30902 L
.84142 .30902 L
.84216 .30902 L
.8435 .30902 L
.84425 .30902 L
.84495 .30902 L
.84571 .30902 L
.84653 .30902 L
.84723 .30902 L
.848 .30902 L
.84872 .30902 L
.84939 .30902 L
.85066 .30902 L
.852 .30902 L
.85326 .30902 L
.85464 .30902 L
.85595 .30902 L
.85716 .30902 L
.85835 .30902 L
.85944 .30902 L
.86069 .30902 L
.86188 .30902 L
.86317 .30902 L
.86453 .30902 L
.8657 .30902 L
.86698 .30902 L
.86836 .30902 L
.86913 .30902 L
.86984 .30902 L
.87121 .30902 L
.8725 .30902 L
.8736 .30902 L
.87482 .30902 L
.87609 .30902 L
.87728 .30902 L
.87839 .30902 L
.87941 .30902 L
.88053 .30902 L
.8817 .30902 L
.8829 .30902 L
.88418 .30902 L
.88539 .30902 L
.88649 .30902 L
.88778 .30902 L
.8885 .30902 L
.88918 .30902 L
.89041 .30902 L
.89172 .30902 L
Mistroke
.89299 .30902 L
.89437 .30902 L
.89568 .30902 L
.89689 .30902 L
.89809 .30902 L
.89918 .30902 L
.90044 .30902 L
.90162 .30902 L
.90292 .30902 L
.90428 .30902 L
.90545 .30902 L
.90673 .30902 L
.90812 .30902 L
.90889 .30902 L
.90959 .30902 L
.91096 .30902 L
.91226 .30902 L
.91337 .30902 L
.91458 .30902 L
.91586 .30902 L
.91705 .30902 L
.91816 .30902 L
.91918 .30902 L
.9203 .30902 L
.92148 .30902 L
.92268 .30902 L
.92396 .30902 L
.92516 .30902 L
.92626 .30902 L
.92755 .30902 L
.92828 .30902 L
.92895 .30902 L
.93018 .30902 L
.93149 .30902 L
.93276 .30902 L
.93348 .30902 L
.93415 .30902 L
.93538 .30902 L
.93668 .30902 L
.93784 .30902 L
.93893 .30902 L
.94013 .30902 L
.94142 .30902 L
.94271 .30902 L
.94344 .30902 L
.94412 .30902 L
.9455 .30902 L
.94627 .30902 L
.94697 .30902 L
.94823 .30902 L
Mistroke
.9496 .30902 L
.95089 .30902 L
.95207 .30902 L
.95318 .30902 L
.95437 .30902 L
.95549 .30902 L
.95652 .30902 L
.95772 .30902 L
.95903 .30902 L
.96027 .30902 L
.96141 .30902 L
.96271 .30902 L
.96393 .30902 L
.96502 .30902 L
.96621 .30902 L
.9675 .30902 L
.96887 .30902 L
.97003 .30902 L
.97131 .30902 L
.97224 .30902 L
.9731 .30902 L
.97404 .30902 L
.97503 .30902 L
.9759 .30902 L
.97671 .30902 L
.9776 .30902 L
.97856 .30902 L
.97936 .30902 L
.98024 .30902 L
.98115 .30902 L
.982 .30902 L
.9828 .30902 L
.98353 .30902 L
.98437 .30902 L
.98516 .30902 L
.98602 .30902 L
.98696 .30902 L
.98795 .30902 L
.98887 .30902 L
.98973 .30902 L
.99051 .30902 L
.99142 .30902 L
.99228 .30902 L
.99321 .30902 L
.9942 .30902 L
.99513 .30902 L
.99598 .30902 L
.99697 .30902 L
.99805 .30902 L
.99907 .30902 L
Mistroke
1 .30902 L
Mfstroke
0 0 1 r
3 Mabswid
0 .30902 m
0 .37082 L
s
.16967 .30902 m
.16967 .37082 L
s
.38057 .30902 m
.38057 .37082 L
s
.57895 .30902 m
.57895 .37082 L
s
.61057 .30902 m
.61057 .37082 L
s
.8477 .30902 m
.8477 .37082 L
s
1 .30902 m
1 .37082 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000P3oool200000300oooo0P0000040?ooo`8000000`3oool4000002T0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002X0
oooo0P0000040?ooo`800000103oool200000300oooo1@0000010?ooo`0000D0oooo0000003oool0
oooo0000000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:@3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000a0?ooo`030000003oool0
oooo0040oooo00001@3oool000000?ooo`3oool0000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:@3oool010000000oooo0?ooo`000009
0?ooo`800000<P3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0?ooo`010?ooo`000P3oool200000300oooo0P00000:0?ooo`800000:P3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002T0oooo0P00000:0?ooo`800000<@3oool2
000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0003
0?ooo`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX
0?ooo`80003o0`3oool000<0oooo0P000?l/000000<0003o>00000030000ocD000000`000?l60000
00<0003o@00000030000obP000000P000?l30?ooo`000`3oool20000o``0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`<0003o1`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`040?ooo`<0003o103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`<0003o103oool00`00
0000oooo0000o`020000o`T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool30000o``0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`80003o0`3oool000<0oooo0P000?l/0?ooo`<0
003o1`3oool00`000000oooo0?ooo`0^0?ooo`<0003o103oool00`000000oooo0?ooo`0^0?ooo`<0
003o103oool00`000000oooo0000o`020000oc<0oooo00<000000?ooo`3oool02P3oool30000obP0
oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo
0`000?m00?ooo`<0003o:03oool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0oooo0`00
0?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3oool000<0oooo0P000?l/
0?ooo`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0003o@03oool30000obP0oooo0P000?l3
0?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?oo
o`<0003o:03oool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0
003o1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3oool000<0oooo0P000?l/0?ooo`<0003o
>03oool30000ocD0oooo0`000?l60?ooo`<0003o@03oool30000obP0oooo0P000?l30?ooo`000`3o
ool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03o
ool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool3
0000od00oooo0`000?lX0?ooo`80003o0`3oool000<0oooo0P000?l/0?ooo`<0003o>03oool30000
ocD0oooo0`000?l60?ooo`<0003o@03oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0
oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0
oooo00030?ooo`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo
0`000?lX0?ooo`80003o0`3oool000<0oooo0P000?l/0?ooo`<0003o>03oool30000ocD0oooo0`00
0?l60?ooo`<0003o@03oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh
0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0oooo00030?oo
o`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?oo
o`80003o0`3oool000<0oooo0P000?l/0?ooo`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0
003o@03oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o
=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0106813, -1.01885, \
0.00355875, 0.0115164}}]
}, Open  ]],

Cell[TextData[{
  "Die Ausf\[UDoubleDot]hrung der beiden letztgenannten Befehle ergibt die \
ersten Teile der Abb. 2.3. Die hier verwendeten Grafikoptionen eignen sich \
besonders f\[UDoubleDot]r eigene kleine Experimente mit den ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Befehlen. Eine Zufallszahl"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(X = Random[]\)], "Input"],

Cell[BoxData[
    \(0.7583545830418578`\)], "Output"]
}, Open  ]],

Cell["kann nun in diese Abbildung eingetragen werden:", "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pl2 = 
        ListPlot[{{X, 0}}, 
          PlotStyle \[Rule] {AbsolutePointSize[8], RGBColor[1, 0, 0]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[pl00, pl2, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[0 .29652 -3 -9 ]
[0 .29652 3 0 ]
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(0)] 0 .29652 0 1 Mshowa
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30902 m
.00123 .30902 L
.00236 .30902 L
.00365 .30902 L
.00488 .30902 L
.00601 .30902 L
.00706 .30902 L
.00821 .30902 L
.00942 .30902 L
.01065 .30902 L
.01196 .30902 L
.0132 .30902 L
.01434 .30902 L
.01566 .30902 L
.01641 .30902 L
.01711 .30902 L
.01839 .30902 L
.01975 .30902 L
.02043 .30902 L
.02115 .30902 L
.02245 .30902 L
.02317 .30902 L
.02384 .30902 L
.02458 .30902 L
.02537 .30902 L
.02605 .30902 L
.02679 .30902 L
.02814 .30902 L
.02945 .30902 L
.03067 .30902 L
.03184 .30902 L
.03295 .30902 L
.03416 .30902 L
.03547 .30902 L
.03676 .30902 L
.03813 .30902 L
.03929 .30902 L
.04057 .30902 L
.04131 .30902 L
.042 .30902 L
.04275 .30902 L
.04355 .30902 L
.0449 .30902 L
.04566 .30902 L
.04637 .30902 L
.0477 .30902 L
.04892 .30902 L
.04959 .30902 L
.05032 .30902 L
.05165 .30902 L
Mistroke
.05245 .30902 L
.05321 .30902 L
.05389 .30902 L
.05462 .30902 L
.05543 .30902 L
.05627 .30902 L
.057 .30902 L
.05779 .30902 L
.05854 .30902 L
.05921 .30902 L
.06 .30902 L
.06074 .30902 L
.06205 .30902 L
.0628 .30902 L
.06349 .30902 L
.06471 .30902 L
.06603 .30902 L
.06727 .30902 L
.06841 .30902 L
.06967 .30902 L
.07105 .30902 L
.07175 .30902 L
.07249 .30902 L
.07383 .30902 L
.07457 .30902 L
.07525 .30902 L
.076 .30902 L
.07679 .30902 L
.07812 .30902 L
.07888 .30902 L
.07959 .30902 L
.0809 .30902 L
.08211 .30902 L
.08349 .30902 L
.08481 .30902 L
.086 .30902 L
.08729 .30902 L
.0885 .30902 L
.08962 .30902 L
.09085 .30902 L
.0922 .30902 L
.09289 .30902 L
.09361 .30902 L
.09493 .30902 L
.09565 .30902 L
.09632 .30902 L
.09705 .30902 L
.09783 .30902 L
.09913 .30902 L
.09987 .30902 L
Mistroke
.10056 .30902 L
.10185 .30902 L
.10303 .30902 L
.10439 .30902 L
.10569 .30902 L
.10691 .30902 L
.10801 .30902 L
.10928 .30902 L
.11048 .30902 L
.1116 .30902 L
.11262 .30902 L
.11375 .30902 L
.11493 .30902 L
.11613 .30902 L
.11742 .30902 L
.11864 .30902 L
.11974 .30902 L
.12104 .30902 L
.12178 .30902 L
.12245 .30902 L
.1237 .30902 L
.12502 .30902 L
.12622 .30902 L
.12753 .30902 L
.12889 .30902 L
.13016 .30902 L
.13135 .30902 L
.13244 .30902 L
.13369 .30902 L
.13487 .30902 L
.13616 .30902 L
.13752 .30902 L
.13868 .30902 L
.13996 .30902 L
.14134 .30902 L
.14211 .30902 L
.14281 .30902 L
.14418 .30902 L
.14548 .30902 L
.14669 .30902 L
.14779 .30902 L
.14906 .30902 L
.15025 .30902 L
.15136 .30902 L
.15237 .30902 L
.15349 .30902 L
.15467 .30902 L
.15586 .30902 L
.15714 .30902 L
.15835 .30902 L
Mistroke
.15945 .30902 L
.16074 .30902 L
.16146 .30902 L
.16214 .30902 L
.16337 .30902 L
.16468 .30902 L
.16594 .30902 L
.16732 .30902 L
.16863 .30902 L
.16984 .30902 L
.17103 .30902 L
.17212 .30902 L
.17337 .30902 L
.17456 .30902 L
.17585 .30902 L
.17721 .30902 L
.17838 .30902 L
.17966 .30902 L
.18104 .30902 L
.18181 .30902 L
.18251 .30902 L
.18388 .30902 L
.18518 .30902 L
.18628 .30902 L
.1875 .30902 L
.18877 .30902 L
.18996 .30902 L
.19107 .30902 L
.19209 .30902 L
.19321 .30902 L
.19438 .30902 L
.19558 .30902 L
.19686 .30902 L
.19807 .30902 L
.19916 .30902 L
.20045 .30902 L
.20118 .30902 L
.20185 .30902 L
.20309 .30902 L
.20439 .30902 L
.20566 .30902 L
.20705 .30902 L
.20835 .30902 L
.20957 .30902 L
.21077 .30902 L
.21186 .30902 L
.21311 .30902 L
.2143 .30902 L
.21559 .30902 L
.21696 .30902 L
Mistroke
.21813 .30902 L
.21941 .30902 L
.22079 .30902 L
.22157 .30902 L
.22227 .30902 L
.22364 .30902 L
.22494 .30902 L
.22604 .30902 L
.22726 .30902 L
.22853 .30902 L
.22973 .30902 L
.23084 .30902 L
.23186 .30902 L
.23297 .30902 L
.23415 .30902 L
.23535 .30902 L
.23663 .30902 L
.23784 .30902 L
.23893 .30902 L
.24023 .30902 L
.24095 .30902 L
.24163 .30902 L
.24286 .30902 L
.24416 .30902 L
.24544 .30902 L
.24683 .30902 L
.24814 .30902 L
.24935 .30902 L
.25044 .30902 L
.25165 .30902 L
.25291 .30902 L
.25409 .30902 L
.25539 .30902 L
.25676 .30902 L
.25793 .30902 L
.25922 .30902 L
.2606 .30902 L
.26137 .30902 L
.26208 .30902 L
.26345 .30902 L
.26475 .30902 L
.26586 .30902 L
.26708 .30902 L
.26835 .30902 L
.26954 .30902 L
.27066 .30902 L
.27168 .30902 L
.27286 .30902 L
.27397 .30902 L
.27518 .30902 L
Mistroke
.27646 .30902 L
.27767 .30902 L
.27876 .30902 L
.28005 .30902 L
.28078 .30902 L
.28145 .30902 L
.28268 .30902 L
.28399 .30902 L
.28527 .30902 L
.28599 .30902 L
.28666 .30902 L
.28789 .30902 L
.28919 .30902 L
.29036 .30902 L
.29145 .30902 L
.29265 .30902 L
.29394 .30902 L
.29524 .30902 L
.29597 .30902 L
.29665 .30902 L
.29803 .30902 L
.29881 .30902 L
.29951 .30902 L
.30077 .30902 L
.30213 .30902 L
.30342 .30902 L
.30461 .30902 L
.30572 .30902 L
.30691 .30902 L
.30804 .30902 L
.30907 .30902 L
.31027 .30902 L
.31158 .30902 L
.31282 .30902 L
.31396 .30902 L
.31526 .30902 L
.31648 .30902 L
.31758 .30902 L
.31876 .30902 L
.32005 .30902 L
.32142 .30902 L
.32259 .30902 L
.32386 .30902 L
.32524 .30902 L
.32651 .30902 L
.32718 .30902 L
.32791 .30902 L
.32867 .30902 L
.32939 .30902 L
.3307 .30902 L
Mistroke
.3319 .30902 L
.33329 .30902 L
.33461 .30902 L
.33578 .30902 L
.33704 .30902 L
.33822 .30902 L
.33929 .30902 L
.34055 .30902 L
.34192 .30902 L
.34321 .30902 L
.3444 .30902 L
.34567 .30902 L
.34703 .30902 L
.34831 .30902 L
.34949 .30902 L
.35086 .30902 L
.35164 .30902 L
.35236 .30902 L
.35368 .30902 L
.35434 .30902 L
.35508 .30902 L
.35579 .30902 L
.35654 .30902 L
.35788 .30902 L
.35863 .30902 L
.35932 .30902 L
.36009 .30902 L
.3609 .30902 L
.36161 .30902 L
.36238 .30902 L
.3631 .30902 L
.36377 .30902 L
.36503 .30902 L
.36637 .30902 L
.36764 .30902 L
.36902 .30902 L
.37033 .30902 L
.37154 .30902 L
.37274 .30902 L
.37383 .30902 L
.37509 .30902 L
.37627 .30902 L
.37756 .30902 L
.37893 .30902 L
.3801 .30902 L
.38138 .30902 L
.38276 .30902 L
.38353 .30902 L
.38424 .30902 L
.38561 .30902 L
Mistroke
.38691 .30902 L
.38801 .30902 L
.38923 .30902 L
.3905 .30902 L
.39169 .30902 L
.3928 .30902 L
.39382 .30902 L
.39494 .30902 L
.39612 .30902 L
.39732 .30902 L
.3986 .30902 L
.3998 .30902 L
.4009 .30902 L
.40219 .30902 L
.40292 .30902 L
.40359 .30902 L
.40482 .30902 L
.40613 .30902 L
.4074 .30902 L
.40879 .30902 L
.4101 .30902 L
.41132 .30902 L
.41252 .30902 L
.41361 .30902 L
.41487 .30902 L
.41605 .30902 L
.41735 .30902 L
.41872 .30902 L
.41989 .30902 L
.42117 .30902 L
.42256 .30902 L
.42333 .30902 L
.42404 .30902 L
.42541 .30902 L
.4267 .30902 L
.42781 .30902 L
.42903 .30902 L
.43031 .30902 L
.4315 .30902 L
.43261 .30902 L
.43363 .30902 L
.43481 .30902 L
.43593 .30902 L
.43713 .30902 L
.43841 .30902 L
.43962 .30902 L
.44071 .30902 L
.44201 .30902 L
.44273 .30902 L
.4434 .30902 L
Mistroke
.44464 .30902 L
.44594 .30902 L
.44722 .30902 L
.44794 .30902 L
.44861 .30902 L
.44984 .30902 L
.45114 .30902 L
.45231 .30902 L
.4534 .30902 L
.4546 .30902 L
.45589 .30902 L
.45718 .30902 L
.45792 .30902 L
.4586 .30902 L
.45998 .30902 L
.46075 .30902 L
.46145 .30902 L
.46271 .30902 L
.46408 .30902 L
.46537 .30902 L
.46656 .30902 L
.46766 .30902 L
.46886 .30902 L
.46998 .30902 L
.47101 .30902 L
.47221 .30902 L
.47352 .30902 L
.47476 .30902 L
.4759 .30902 L
.4772 .30902 L
.47842 .30902 L
.47952 .30902 L
.4807 .30902 L
.48199 .30902 L
.48336 .30902 L
.48453 .30902 L
.4858 .30902 L
.48718 .30902 L
.48845 .30902 L
.48911 .30902 L
.48984 .30902 L
.49061 .30902 L
.49132 .30902 L
.49264 .30902 L
.49384 .30902 L
.49516 .30902 L
.49655 .30902 L
.49772 .30902 L
.49897 .30902 L
.50015 .30902 L
Mistroke
.50122 .30902 L
.50248 .30902 L
.50385 .30902 L
.50514 .30902 L
.50633 .30902 L
.5076 .30902 L
.50896 .30902 L
.51024 .30902 L
.51142 .30902 L
.51279 .30902 L
.51357 .30902 L
.51429 .30902 L
.5156 .30902 L
.51627 .30902 L
.51701 .30902 L
.51772 .30902 L
.51847 .30902 L
.51981 .30902 L
.52055 .30902 L
.52125 .30902 L
.52201 .30902 L
.52283 .30902 L
.52354 .30902 L
.5243 .30902 L
.52503 .30902 L
.52569 .30902 L
.52696 .30902 L
.5283 .30902 L
.52957 .30902 L
.53095 .30902 L
.53225 .30902 L
.53347 .30902 L
.53467 .30902 L
.53575 .30902 L
.53701 .30902 L
.53819 .30902 L
.53948 .30902 L
.54085 .30902 L
.54202 .30902 L
.5433 .30902 L
.54468 .30902 L
.54545 .30902 L
.54616 .30902 L
.54753 .30902 L
.54882 .30902 L
.54993 .30902 L
.55114 .30902 L
.55241 .30902 L
.55361 .30902 L
.55472 .30902 L
Mistroke
.55574 .30902 L
.55685 .30902 L
.55803 .30902 L
.55923 .30902 L
.56051 .30902 L
.56172 .30902 L
.56281 .30902 L
.5641 .30902 L
.56483 .30902 L
.5655 .30902 L
.56674 .30902 L
.56804 .30902 L
.56932 .30902 L
.5707 .30902 L
.57201 .30902 L
.57323 .30902 L
.57443 .30902 L
.57552 .30902 L
.57678 .30902 L
.57796 .30902 L
.57926 .30902 L
.58063 .30902 L
.5818 .30902 L
.58308 .30902 L
.58446 .30902 L
.58524 .30902 L
.58594 .30902 L
.58731 .30902 L
.58861 .30902 L
.58971 .30902 L
.59093 .30902 L
.59221 .30902 L
.5934 .30902 L
.59451 .30902 L
.59553 .30902 L
.59671 .30902 L
.59783 .30902 L
.59903 .30902 L
.60031 .30902 L
.60152 .30902 L
.60261 .30902 L
.60391 .30902 L
.60463 .30902 L
.6053 .30902 L
.60654 .30902 L
.60784 .30902 L
.60912 .30902 L
.60984 .30902 L
.61051 .30902 L
.61174 .30902 L
Mistroke
.61304 .30902 L
.6142 .30902 L
.61529 .30902 L
.61649 .30902 L
.61778 .30902 L
.61908 .30902 L
.61981 .30902 L
.62049 .30902 L
.62187 .30902 L
.62264 .30902 L
.62335 .30902 L
.6246 .30902 L
.62597 .30902 L
.62726 .30902 L
.62845 .30902 L
.62955 .30902 L
.63075 .30902 L
.63187 .30902 L
.6329 .30902 L
.6341 .30902 L
.63541 .30902 L
.63665 .30902 L
.63779 .30902 L
.63909 .30902 L
.64031 .30902 L
.6414 .30902 L
.64259 .30902 L
.64388 .30902 L
.64525 .30902 L
.64641 .30902 L
.64769 .30902 L
.64907 .30902 L
.65034 .30902 L
.651 .30902 L
.65173 .30902 L
.65249 .30902 L
.65321 .30902 L
.65452 .30902 L
.65572 .30902 L
.65704 .30902 L
.65843 .30902 L
.6596 .30902 L
.66085 .30902 L
.66203 .30902 L
.6631 .30902 L
.66436 .30902 L
.66573 .30902 L
.66702 .30902 L
.66821 .30902 L
.66947 .30902 L
Mistroke
.67083 .30902 L
.67212 .30902 L
.67329 .30902 L
.67467 .30902 L
.67544 .30902 L
.67616 .30902 L
.67748 .30902 L
.67815 .30902 L
.67888 .30902 L
.67959 .30902 L
.68034 .30902 L
.68168 .30902 L
.68243 .30902 L
.68312 .30902 L
.68389 .30902 L
.6847 .30902 L
.68541 .30902 L
.68618 .30902 L
.6869 .30902 L
.68757 .30902 L
.68883 .30902 L
.69018 .30902 L
.69144 .30902 L
.69282 .30902 L
.69413 .30902 L
.69534 .30902 L
.69654 .30902 L
.69762 .30902 L
.69888 .30902 L
.70006 .30902 L
.70135 .30902 L
.70272 .30902 L
.70388 .30902 L
.70517 .30902 L
.70654 .30902 L
.70732 .30902 L
.70802 .30902 L
.70939 .30902 L
.71069 .30902 L
.71179 .30902 L
.71301 .30902 L
.71428 .30902 L
.71547 .30902 L
.71658 .30902 L
.7176 .30902 L
.71872 .30902 L
.71989 .30902 L
.72109 .30902 L
.72237 .30902 L
.72358 .30902 L
Mistroke
.72468 .30902 L
.72597 .30902 L
.72669 .30902 L
.72737 .30902 L
.7286 .30902 L
.72991 .30902 L
.73118 .30902 L
.73256 .30902 L
.73387 .30902 L
.73508 .30902 L
.73629 .30902 L
.73738 .30902 L
.73863 .30902 L
.73982 .30902 L
.74111 .30902 L
.74248 .30902 L
.74365 .30902 L
.74493 .30902 L
.74631 .30902 L
.74709 .30902 L
.74779 .30902 L
.74916 .30902 L
.75046 .30902 L
.75157 .30902 L
.75279 .30902 L
.75406 .30902 L
.75525 .30902 L
.75636 .30902 L
.75738 .30902 L
.7585 .30902 L
.75968 .30902 L
.76088 .30902 L
.76216 .30902 L
.76337 .30902 L
.76446 .30902 L
.76575 .30902 L
.76648 .30902 L
.76715 .30902 L
.76839 .30902 L
.76969 .30902 L
.77097 .30902 L
.77169 .30902 L
.77236 .30902 L
.77358 .30902 L
.77489 .30902 L
.77605 .30902 L
.77714 .30902 L
.77834 .30902 L
.77963 .30902 L
.78092 .30902 L
Mistroke
.78165 .30902 L
.78233 .30902 L
.78371 .30902 L
.78448 .30902 L
.78519 .30902 L
.78644 .30902 L
.78781 .30902 L
.7891 .30902 L
.79029 .30902 L
.79139 .30902 L
.79258 .30902 L
.79371 .30902 L
.79473 .30902 L
.79593 .30902 L
.79724 .30902 L
.79848 .30902 L
.79963 .30902 L
.80093 .30902 L
.80214 .30902 L
.80324 .30902 L
.80442 .30902 L
.80572 .30902 L
.80708 .30902 L
.80825 .30902 L
.80953 .30902 L
.8109 .30902 L
.81217 .30902 L
.81283 .30902 L
.81356 .30902 L
.81432 .30902 L
.81504 .30902 L
.81635 .30902 L
.81755 .30902 L
.81887 .30902 L
.82026 .30902 L
.82143 .30902 L
.82268 .30902 L
.82386 .30902 L
.82493 .30902 L
.82619 .30902 L
.82755 .30902 L
.82884 .30902 L
.83003 .30902 L
.8313 .30902 L
.83266 .30902 L
.83394 .30902 L
.83512 .30902 L
.83649 .30902 L
.83727 .30902 L
.83798 .30902 L
Mistroke
.8393 .30902 L
.84004 .30902 L
.84071 .30902 L
.84142 .30902 L
.84216 .30902 L
.8435 .30902 L
.84425 .30902 L
.84495 .30902 L
.84571 .30902 L
.84653 .30902 L
.84723 .30902 L
.848 .30902 L
.84872 .30902 L
.84939 .30902 L
.85066 .30902 L
.852 .30902 L
.85326 .30902 L
.85464 .30902 L
.85595 .30902 L
.85716 .30902 L
.85835 .30902 L
.85944 .30902 L
.86069 .30902 L
.86188 .30902 L
.86317 .30902 L
.86453 .30902 L
.8657 .30902 L
.86698 .30902 L
.86836 .30902 L
.86913 .30902 L
.86984 .30902 L
.87121 .30902 L
.8725 .30902 L
.8736 .30902 L
.87482 .30902 L
.87609 .30902 L
.87728 .30902 L
.87839 .30902 L
.87941 .30902 L
.88053 .30902 L
.8817 .30902 L
.8829 .30902 L
.88418 .30902 L
.88539 .30902 L
.88649 .30902 L
.88778 .30902 L
.8885 .30902 L
.88918 .30902 L
.89041 .30902 L
.89172 .30902 L
Mistroke
.89299 .30902 L
.89437 .30902 L
.89568 .30902 L
.89689 .30902 L
.89809 .30902 L
.89918 .30902 L
.90044 .30902 L
.90162 .30902 L
.90292 .30902 L
.90428 .30902 L
.90545 .30902 L
.90673 .30902 L
.90812 .30902 L
.90889 .30902 L
.90959 .30902 L
.91096 .30902 L
.91226 .30902 L
.91337 .30902 L
.91458 .30902 L
.91586 .30902 L
.91705 .30902 L
.91816 .30902 L
.91918 .30902 L
.9203 .30902 L
.92148 .30902 L
.92268 .30902 L
.92396 .30902 L
.92516 .30902 L
.92626 .30902 L
.92755 .30902 L
.92828 .30902 L
.92895 .30902 L
.93018 .30902 L
.93149 .30902 L
.93276 .30902 L
.93348 .30902 L
.93415 .30902 L
.93538 .30902 L
.93668 .30902 L
.93784 .30902 L
.93893 .30902 L
.94013 .30902 L
.94142 .30902 L
.94271 .30902 L
.94344 .30902 L
.94412 .30902 L
.9455 .30902 L
.94627 .30902 L
.94697 .30902 L
.94823 .30902 L
Mistroke
.9496 .30902 L
.95089 .30902 L
.95207 .30902 L
.95318 .30902 L
.95437 .30902 L
.95549 .30902 L
.95652 .30902 L
.95772 .30902 L
.95903 .30902 L
.96027 .30902 L
.96141 .30902 L
.96271 .30902 L
.96393 .30902 L
.96502 .30902 L
.96621 .30902 L
.9675 .30902 L
.96887 .30902 L
.97003 .30902 L
.97131 .30902 L
.97224 .30902 L
.9731 .30902 L
.97404 .30902 L
.97503 .30902 L
.9759 .30902 L
.97671 .30902 L
.9776 .30902 L
.97856 .30902 L
.97936 .30902 L
.98024 .30902 L
.98115 .30902 L
.982 .30902 L
.9828 .30902 L
.98353 .30902 L
.98437 .30902 L
.98516 .30902 L
.98602 .30902 L
.98696 .30902 L
.98795 .30902 L
.98887 .30902 L
.98973 .30902 L
.99051 .30902 L
.99142 .30902 L
.99228 .30902 L
.99321 .30902 L
.9942 .30902 L
.99513 .30902 L
.99598 .30902 L
.99697 .30902 L
.99805 .30902 L
.99907 .30902 L
Mistroke
1 .30902 L
Mfstroke
0 0 1 r
3 Mabswid
0 .30902 m
0 .37082 L
s
.16967 .30902 m
.16967 .37082 L
s
.38057 .30902 m
.38057 .37082 L
s
.57895 .30902 m
.57895 .37082 L
s
.61057 .30902 m
.61057 .37082 L
s
.8477 .30902 m
.8477 .37082 L
s
1 .30902 m
1 .37082 L
s
1 0 0 r
8 Mabswid
.75835 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000P3oool200000300oooo0P0000040?ooo`8000000`3oool4000002T0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002X0
oooo0P0000040?ooo`800000103oool200000300oooo1@0000010?ooo`0000D0oooo0000003oool0
oooo0000000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:@3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002P0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000a0?ooo`030000003oool0
oooo0040oooo00001@3oool000000?ooo`3oool0000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:@3oool010000000oooo0?ooo`000009
0?ooo`800000<P3oool00`000000oooo0?ooo`010?ooo`0000D0oooo0000003oool0oooo0000000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0?ooo`010?ooo`000P3oool200000300oooo0P00000:0?ooo`800000:P3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002T0oooo0P00000:0?ooo`800000<@3oool2
000000<0oooo003o0?ooob40oooo003o0?ooob40oooo003G0?ooo`80o`00A`3oool00=D0oooo1P3o
00150?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?lU
0?ooo`H0o`005@3oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`000000`000?lh0000
00<0003o=@0000030000o`H000000`000?lT000000P0o`00500000030000obP000000P000?l30?oo
o`000`3oool20000o``0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo0?ooo`<0003o1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`<0003o103oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`040?ooo`<0003o103oool00`000000oooo0000o`020000o`T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`P0o`001`3oool00`000000oooo0?ooo`0:0?oo
o`<0003o303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0P000?l30?oo
o`000`3oool20000ob`0oooo0`000?l70?ooo`030000003oool0oooo02h0oooo0`000?l40?ooo`03
0000003oool0oooo02h0oooo0`000?l40?ooo`030000003oool0003o0080003o9@3oool60?l000P0
oooo00<000000?ooo`3oool02P3oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo
0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?lU0?ooo`H0o`005@3oool30000obP0oooo
0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`00
0?lW0?ooo`80o`005`3oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh
0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0oooo00030?oo
o`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?oo
o`80003o0`3oool000<0oooo0P000?l/0?ooo`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0
003o@03oool30000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o
=@3oool30000o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0oooo00030?ooo`80003o;03o
ool30000ocP0oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3o
ool000<0oooo0P000?l/0?ooo`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0003o@03oool3
0000obP0oooo0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000
o`H0oooo0`000?m00?ooo`<0003o:03oool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0
oooo0`000?le0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3oool000<0oooo
0P000?l/0?ooo`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0003o@03oool30000obP0oooo
0P000?l30?ooo`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`00
0?m00?ooo`<0003o:03oool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0oooo0`000?le
0?ooo`<0003o1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3oool000<0oooo0P000?l/0?oo
o`<0003o>03oool30000ocD0oooo0`000?l60?ooo`<0003o@03oool30000obP0oooo0P000?l30?oo
o`000`3oool20000ob`0oooo0`000?lh0?ooo`<0003o=@3oool30000o`H0oooo0`000?m00?ooo`<0
003o:03oool20000o`<0oooo00030?ooo`80003o;03oool30000ocP0oooo0`000?le0?ooo`<0003o
1P3oool30000od00oooo0`000?lX0?ooo`80003o0`3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0106813, -1.01885, \
0.00355875, 0.0115164}}]
}, Open  ]],

Cell[TextData[{
  "Das zugeh\[ODoubleDot]rige Ergebnis, also die Intervallnummer oder - in \
dem Gedankenexperiment dieses Kapitels - die von dem W\[UDoubleDot]rfel, der \
dieser Wahrscheinlichkeitsverteilung folgt, ausgegebene Zahl, kann man nun \
\[UDoubleDot]ber einen kleinen Umweg ermitteln. Dazu f\[UDoubleDot]gt man die \
Zahl ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " der Liste von Intervallgrenzen hinzu (mit ",
  StyleBox["Append",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "), sortiert die Eintr\[ADoubleDot]ge dieser Liste nach ihrer Gr\
\[ODoubleDot]\[SZ]e (mit ",
  StyleBox["Sort",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") und l\[ADoubleDot]sst sich die Position von ",
  StyleBox["X",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " in der sortierten Liste ausgeben (mit ",
  StyleBox["Position",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "). Subtrahiert man Eins (sonst w\[UDoubleDot]rden die \
m\[ODoubleDot]glichen Ergebnisse zwischen 2 und 7 liegen), so \
erh\[ADoubleDot]lt man die Intervallnummer:"
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Position[Sort[Append[cumDist, X]], X]\)[\([1, 1]\)]\  - 1\)], "Input"],

Cell[BoxData[
    \(5\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Damit haben wir Abb. 2.3 vollst\[ADoubleDot]ndig in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " reproduziert. Zugleich haben wir ein mathematisch nicht triviales Objekt \
implementiert, n\[ADoubleDot]mlich eine Routine, die eine zwischen Null und \
Eins gleichverteilte kontinuierliche Zufallszahl in eine diskrete Zufallszahl \
\[UDoubleDot]berf\[UDoubleDot]hrt, die einer vorgegebenen \
Wahrscheinlichkeitsverteilung folgt. Diese Aussage k\[ODoubleDot]nnen wir nun \
\[UDoubleDot]berpr\[UDoubleDot]fen. Abbildung 2.4 zeigt eine Abfolge von zehn \
Zufallsexperimenten mit jeweils zehn Eintr\[ADoubleDot]gen. Die erheblichen \
Unterschiede zwischen den Punktverteilungen zeigen deutlich, dass zehn \
Wiederholungen keinesfalls ausreichen, um die zugrunde liegende \
Wahrscheinlichkeitsverteilung angemessen abzubilden. Abbildung 2.5 zeigt drei \
H\[ADoubleDot]ufigkeitsverteilungen f\[UDoubleDot]r unterschiedliche \
Stichprobengr\[ODoubleDot]\[SZ]en, sowie die tats\[ADoubleDot]chliche \
Verteilung. Der optische Eindruck aus Abb. 2.4 best\[ADoubleDot]tigt sich: \
Mit nur zehn Wiederholungen des Einzelereignisses lassen sich die Intervallgr\
\[ODoubleDot]\[SZ]en nur unzureichend nachzeichnen. Mit wachsender Zahl der \
Wiederholungen (Stichprobengr\[ODoubleDot]\[SZ]e) approximieren die relativen \
H\[ADoubleDot]ufigkeiten jedoch immer besser die Intervallgrenzen (Abb. 2.5 \
d)."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(\(\ \)\(SeedRandom[1]\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rand = Table[Random[], {6}]\)], "Input"],

Cell[BoxData[
    \({0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
      0.12463419022903224`, 0.9345372830959425`, 
      0.6002520340808316`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[\ 
      plTab\ \  = 
        Map[\ ListPlot[{{#, 0}}, 
              PlotStyle \[Rule] {AbsolutePointSize[6], RGBColor[1, 0, 0]}, 
              DisplayFunction \[Rule] Identity] &, \ 
          Table[Random[], {10}]]; \n
      Show[Flatten[{pl00, plTab}], DisplayFunction \[Rule] $DisplayFunction, 
        AspectRatio \[Rule] 0.1];, {jj, 1, 10}]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.75835 .05 Mdot
.96909 .05 Mdot
.1257 .05 Mdot
.57564 .05 Mdot
.75505 .05 Mdot
.82144 .05 Mdot
.6046 .05 Mdot
.19446 .05 Mdot
.65731 .05 Mdot
.55956 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000W0?ooo`80o`004@3o
ool20?l006<0oooo0P3o00020?ooo`80o`001`3oool20?l000`0oooo0P3o000I0?ooo`<0o`00403o
ool20?l002L0oooo0P3o000=0?ooo`009P3oool40?l000l0oooo103o001Q0?ooo`P0o`001@3oool4
0?l000X0oooo103o000G0?ooo`D0o`003P3oool40?l002D0oooo103o000<0?ooo`00103oool20000
oal0oooo1P3o00070?ooo`<0003o0`3oool60?l002l0oooo0`000?l]0?ooo`X0o`000`3oool60?l0
00P0oooo1P3o000E0?ooo`L0o`00303oool60?l00080oooo0`000?lN0?ooo`H0o`00103oool20000
o`D0oooo00040?ooo`80003o7`0000060?l000L000000`000?l3000000H0o`00;`0000030000obd0
00002P3o0003000000H0o`00200000060?l001D000001`3o000<000000H0o`000P0000030000oah0
00001P3o000400000080003o1@3oool000@0oooo0P000?l<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool40?l000@0oooo00@000000?ooo`3oool0oooo0`000?l40?ooo`@0
o`003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool30000o`<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?l0003o00001P3o00000`000?l0oooo0?ooo`020?ooo`@0
o`0000<0003o0?ooo`3oool01`3oool40?l000X0oooo00<000000?ooo`3oool02P3oool50?l000T0
oooo00<000000?ooo`3oool00P3oool40?l000<0oooo0`000?l=0?ooo`030000003oool0oooo00/0
oooo00@000000?ooo`3oool0oooo103o00050?ooo`80003o1@3oool000@0oooo0P000?lQ0?ooo`80
o`002@3oool30000o`D0oooo0P3o000a0?ooo`<0003o;`3oool20?l00080oooo0P3o00020000o`D0
oooo0P3o00020000o`X0oooo0P3o000I0?ooo`<0o`00403oool20?l000@0oooo0`000?lP0?ooo`80
o`001P3oool20000o`D0oooo00040?ooo`80003o;03oool30000ocP0oooo0`000?ld0?ooo`<0003o
1P3oool30000och0oooo0`000?lX0?ooo`80003o1@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.83673 .05 Mdot
.16054 .05 Mdot
.85444 .05 Mdot
.94544 .05 Mdot
.93718 .05 Mdot
.26092 .05 Mdot
.72729 .05 Mdot
.27913 .05 Mdot
.26849 .05 Mdot
.42972 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000`0?ooo`80o`006P3o
ool40?l000030?ooo`3o0000o`0002P0oooo0P3o001A0?ooo`80o`00703oool20?l000<0oooo0P3o
000E0?ooo`@0o`00503oool002l0oooo103o000H0?ooo`T0o`009P3oool40?l004l0oooo103o000J
0?ooo`@0o`0000<0oooo0?l0003o00000P3o000C0?ooo`H0o`004`3oool000@0oooo0P000?lX0?oo
o`H0o`0000<0003o0?ooo`3oool04`3oool;0?l001P0oooo0`000?l90?ooo`H0o`009@3oool30000
o`H0oooo0`000?lL0?ooo`H0o`00603oool;0?l00140oooo203o000;0?ooo`80003o1@3oool000@0
oooo0P000?lX000000H0o`0000<0003o0000000000004`00000;0?l001P000000`000?l9000000H0
o`009@0000030000o`H000000`000?lL000000H0o`006000000;0?l001400000203o000;00000080
003o1@3oool000@0oooo0P000?l<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000o`000?l000020?l00080003o1`3oool00`000000oooo0?ooo`0;0?ooo`030000
003o0000o`0000L0o`00103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
0`000?l30?ooo`030000003oool0oooo00@0oooo103o00030?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`<0003o103oool00`000000oooo
0000o`020000o`T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`@0o`00
0`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo103o00000`000?l0o`00
0?l000020?l000X0oooo00<000000?ooo`3oool01P3oool60?l000`0oooo0P000?l50?ooo`00103o
ool20000obX0oooo0P3o00030000oaL0oooo103o00000`3oool0o`000?l0000J0?ooo`<0003o2`3o
ool20?l002L0oooo0`000?l60?ooo`<0003o7P3oool20?l001`0oooo0P3o00030000o`80o`005@3o
ool40?l000d0oooo0P000?l50?ooo`00103oool20000ob`0oooo0`000?lh0?ooo`<0003o=03oool3
0000o`H0oooo0`000?ln0?ooo`<0003o:03oool20000o`D0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.94548 .05 Mdot
.1545 .05 Mdot
.33395 .05 Mdot
.82947 .05 Mdot
.18713 .05 Mdot
.18541 .05 Mdot
.20825 .05 Mdot
.25383 .05 Mdot
.43207 .05 Mdot
.36397 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000_0?ooo`80o`001P3o
ool30?l000@0oooo0P3o000:0?ooo`80o`00503oool20?l000L0oooo0P3o000A0?ooo`80o`00K03o
ool20?l001h0oooo0P3o000D0?ooo`00;P3oool40?l000@0oooo1@3o00020?ooo`@0o`00203oool4
0?l00180oooo103o00050?ooo`@0o`003`3oool40?l006X0oooo103o000L0?ooo`@0o`004`3oool0
00@0oooo0P000?lW0?ooo`H0o`000P000?l=0?l000H0oooo1P3o000@0?ooo`H0o`000`3oool60?l0
00<0003o2P3oool60?l002@0oooo0`000?l60?ooo`<0003o>03oool60?l000<0003o5`3oool60?l0
00/0oooo0P000?l50?ooo`00103oool20000obL000001P3o00020000o`d0o`001P0000060?l00100
00001P3o0003000000H0o`000`000?l:000000H0o`00900000030000o`H000000`000?lh000000H0
o`000`000?lG000000H0o`002`0000020000o`D0oooo00040?ooo`80003o303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo103o00030000o`030?ooo`3o0000o`0000<0o`00
00<0oooo0000003o00000`3o00080?ooo`@0o`002`3oool00`000000oooo0?ooo`040?ooo`@0o`00
0P3oool00`000000oooo0?ooo`040?l000040?ooo`000?l0003o0000o`<0oooo00<000000?ooo`3o
ool01@3oool40?l00080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00@0oooo0`000?l40?ooo`030000003oool0003o0080003o2@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`040?ooo`@0o`0000@0oooo0000o`000?l0003o3@3oool00`000000oooo0?ooo`080?oo
o`@0o`00303oool20000o`D0oooo00040?ooo`80003o:@3oool20?l000040?ooo`000?l0003o0000
o`80oooo0`3o00040?ooo`80o`002P3oool20?l001@0oooo0P3o00070?ooo`80o`000P3oool30000
o``0oooo0P3o000V0?ooo`<0003o1P3oool30000ocX0oooo0P3o00020?ooo`<0003o6@3oool20?l0
00d0oooo0P000?l50?ooo`00103oool20000ob`0oooo0`000?lh0?ooo`<0003o=03oool30000o`H0
oooo0`000?ln0?ooo`<0003o:03oool20000o`D0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.60365 .05 Mdot
.05936 .05 Mdot
.77477 .05 Mdot
.80441 .05 Mdot
.76692 .05 Mdot
.89883 .05 Mdot
.92033 .05 Mdot
.85898 .05 Mdot
.82974 .05 Mdot
.63791 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000D0?ooo`80o`00U@3o
ool20?l000P0oooo0P3o000R0?ooo`@0o`001P3oool20?l000D0oooo0P3o00060?ooo`80o`002@3o
ool20?l000@0oooo0P3o000K0?ooo`004`3oool40?l009<0oooo103o00060?ooo`@0o`00803oool6
0?l000@0oooo103o00030?ooo`@0o`00103oool40?l000L0oooo103o00020?ooo`@0o`006P3oool0
00@0oooo0P000?l<0?ooo`H0o`006P3oool30000ocP0oooo0`000?ld0?ooo`<0003o0P3oool60?l0
00040000o`3oool0oooo0?ooo`H0o`007P3oool80?l00080oooo1P3o00000`3oool0o`000?l00004
0?l00080003o1P3o00050?ooo``0o`004P3oool20000o`D0oooo00040?ooo`80003o300000060?l0
01X000000`000?lh000000<0003o=00000030000o`8000001P3o000010000?l00000000000000006
0?l001h00000203o0002000000H0o`0000<000000?l0003o0000103o00020000o`H0o`001@00000<
0?l0018000000P000?l50?ooo`00103oool20000o``0oooo00<000000?l0003o00000P3o00090?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0`000?l70?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo0`000?l30?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo0`000?l30?ooo`@0o`000P000?l4
0?ooo`@0o`0000<0oooo0000003oool0303oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo0?ooo`H0o`00103oool40?l000<0oooo103o0000103oool0003o0000o`000?l40?l000L0oooo
103o00020?ooo`@0o`001P3oool00`000000oooo0?ooo`0:0?ooo`80003o1@3oool000@0oooo0P00
0?l>0?ooo`80o`00703oool30000ocP0oooo0`000?ld0?ooo`<0003o103oool20?l000<0003o1@3o
ool20?l00280oooo103o00060?ooo`80o`001@3oool20?l00080oooo0`000?l00`3oool0o`000?l0
00090?ooo`80o`00103oool20?l001@0oooo0P000?l50?ooo`00103oool20000ob`0oooo0`000?lh
0?ooo`<0003o=03oool30000o`H0oooo0`000?ln0?ooo`<0003o:03oool20000o`D0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.19304 .05 Mdot
.57984 .05 Mdot
.56125 .05 Mdot
.20819 .05 Mdot
.24756 .05 Mdot
.42535 .05 Mdot
.2273 .05 Mdot
.37873 .05 Mdot
.06044 .05 Mdot
.23994 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?ooo`80o`008P3o
ool20?l000<0oooo0P3o00030?ooo`80o`0000<0oooo0?l0003o00000P3o000S0?ooo`80o`002`3o
ool20?l002<0oooo0P3o00040?ooo`80o`00N@3oool001@0oooo103o000P0?ooo`@0o`0000<0oooo
0?l0003o00000P3o00000`3oool0o`000?l000070?l00240oooo103o00090?ooo`@0o`008@3oool4
0?l00080oooo103o001h0?ooo`00103oool20000o`d0oooo1P3o000I0?ooo`<0003o0P3ooolE0?l0
01l0oooo1P3o00070?ooo`H0o`007`3oool<0?l000@0oooo0`000?ln0?ooo`<0003o:03oool20000
o`D0oooo00040?ooo`80003o3@0000060?l001T000000`000?l2000001D0o`007`0000060?l000L0
00001P3o000O000000`0o`00100000030000och000000`000?lX00000080003o1@3oool000@0oooo
0P000?l<0?ooo`030000003oool0o`0000<0o`00203oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo0?ooo`<0003o0`3oool40?l000030000003o0000o`000080o`0000<0oooo0?l0003o
00001`3o000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool40?l000<0
oooo00<000000?ooo`3oool00`3oool40?l000@0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003o0000o`000080o`000P3oool40?l000<0oooo00<000000?ooo`00
0?l00P000?l90?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0`000?l=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool20000o`D0oooo00040?ooo`80003o3`3oool20?l001/0oooo
0`000?l40?ooo`80o`000`3oool20?l000<0oooo0P3o00000`3oool0o`000?l000020?l002<0oooo
0P3o00000`000?l0oooo0?ooo`080?ooo`80o`008`3oool20?l000<0oooo00<0003o0?l0003o0000
1P3oool30000och0oooo0`000?lX0?ooo`80003o1@3oool000@0oooo0P000?l/0?ooo`<0003o>03o
ool30000oc@0oooo0`000?l60?ooo`<0003o?P3oool30000obP0oooo0P000?l50?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.01904 .05 Mdot
.1249 .05 Mdot
.62836 .05 Mdot
.87597 .05 Mdot
.41539 .05 Mdot
.06554 .05 Mdot
.8536 .05 Mdot
.07156 .05 Mdot
.64847 .05 Mdot
.16671 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00090?ooo`80o`002`3o
ool40?l000`0oooo0P3o000:0?ooo`80o`00@`3oool20?l003T0oooo0P3o00040?ooo`80o`00=`3o
ool20?l000@0oooo0P3o000W0?ooo`00203oool40?l000T0oooo1P3o000:0?ooo`@0o`00203oool4
0?l00440oooo103o000g0?ooo`@0o`000P3oool40?l003D0oooo103o00020?ooo`@0o`009P3oool0
00@0oooo0P000?l00`3oool0o`000?l000040?l000L0oooo203o00080?ooo`H0o`001P3oool60?l0
03L0oooo0`000?l50?ooo`H0o`00:@3oool30000o`H0oooo0`000?l<0?l00380oooo00<0003o0?l0
003o00002P3o000N0?ooo`80003o1@3oool000@0oooo0P000?l00`000000o`000?l000040?l000L0
0000203o0008000000H0o`001P0000060?l003L000000`000?l5000000H0o`00:@0000030000o`H0
00000`000?l<0?l00380000000<0003o0?l0003o00002P3o000N00000080003o1@3oool000@0oooo
0P000?l20?ooo`@0o`001P3oool00`000000oooo0?ooo`060?l000D0oooo00<000000?ooo`3oool0
0P3oool40?l000D0oooo00<000000?ooo`3oool0103o00070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
0`000?l30?ooo`030000003oool0oooo00@0o`001`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0103oool30000o`@0oooo00<000000?ooo`000?l0
0P000?l00`3oool0o`000?l000020?l00080oooo103o000<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`80003o103o00020?ooo`@0o`00
103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo0P000?l50?ooo`00103o
ool20000o`<0oooo0P3o000;0?ooo`@0o`00303oool20?l000X0oooo0P3o00000`000?l0oooo0?oo
o`0f0?ooo`<0003o1`3oool20?l002/0oooo0`000?l60?ooo`<0003o0P3oool20?l000@0oooo0P3o
000d0?ooo`<0003o0P3o00040?ooo`80o`00803oool20000o`D0oooo00040?ooo`80003o;03oool3
0000ocP0oooo0`000?ld0?ooo`<0003o1P3oool30000och0oooo0`000?lX0?ooo`80003o1@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.93327 .05 Mdot
.21258 .05 Mdot
.81873 .05 Mdot
.5288 .05 Mdot
.74022 .05 Mdot
.63274 .05 Mdot
.25748 .05 Mdot
.3206 .05 Mdot
.49266 .05 Mdot
.20739 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000m0?ooo`@0o`002P3o
ool20?l00100oooo0P3o000]0?ooo`80o`00203oool20?l001/0oooo0P3o000L0?ooo`80o`00503o
ool20?l001h0oooo0P3o000G0?ooo`00?03oool60?l000P0oooo103o000>0?ooo`@0o`00:`3oool4
0?l000H0oooo103o000I0?ooo`@0o`006P3oool40?l00180oooo103o000L0?ooo`@0o`005P3oool0
00@0oooo0P000?l/0?ooo`<0003o1P3oool80?l000H0oooo1P3o000<0?ooo`H0o`00303oool30000
oaX0oooo1P3o00040?ooo`H0o`002P3oool30000o`H0oooo0`000?l00`3oool0o`000?l000040?l0
01P0oooo1P3o000@0?ooo`H0o`000`3oool30000oa@0oooo1P3o000>0?ooo`80003o1@3oool000@0
oooo0P000?l/000000<0003o1P0000080?l000H000001P3o000<000000H0o`00300000030000oaX0
00001P3o0004000000H0o`002P0000030000o`H000000`000?l00`000000o`000?l000040?l001P0
00001P3o000@000000H0o`000`0000030000oa@000001P3o000>00000080003o1@3oool000@0oooo
0P000?l<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool010000000oooo
0?ooo`3oool30000o`L0oooo1P3o00080?ooo`@0o`002P3oool010000000oooo0?ooo`3oool40?l0
00D0oooo00<000000?ooo`3oool01@3oool30000o`<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`@0o`0000<000000?ooo`3oool00`3oool40?l000@0oooo00<000000?oo
o`3oool0103oool30000o`@0oooo00<000000?ooo`000?l00P000?l20?ooo`@0o`000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo103o00000`000000oooo0?ooo`0;0?oo
o`040000003oool0oooo0?ooo`@0o`00103oool30000o`d0oooo00<000000?ooo`3oool01@3oool4
0?l00080oooo00<000000?ooo`3oool02P3oool20000o`D0oooo00040?ooo`80003o;03oool30000
o`P0oooo103o000:0?ooo`80o`00403oool20?l000h0oooo0`000?lL0?ooo`80o`00203oool20?l0
00`0oooo0`000?l60?ooo`<0003o0`3oool20?l001`0oooo0P3o000D0?ooo`80o`001@3oool30000
oaH0oooo0P3o000@0?ooo`80003o1@3oool000@0oooo0P000?l/0?ooo`<0003o>03oool30000oc@0
oooo0`000?l60?ooo`<0003o?P3oool30000obP0oooo0P000?l50?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.03019 .05 Mdot
.94187 .05 Mdot
.43222 .05 Mdot
.96745 .05 Mdot
.01114 .05 Mdot
.81697 .05 Mdot
.80386 .05 Mdot
.09148 .05 Mdot
.59575 .05 Mdot
.75144 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00070?ooo`80o`000`3o
ool20?l000l0oooo0P3o001M0?ooo`80o`00:`3oool20?l002T0oooo0P3o000=0?ooo`80o`0000<0
oooo0?l0003o00008@3oool20?l000D0oooo0P3o000>0?ooo`001P3oool40?l000030?ooo`3o0000
o`000080o`003@3oool40?l005/0oooo103o000Y0?ooo`@0o`009`3oool40?l000/0oooo1`3o000O
0?ooo`@0o`000`3oool40?l000d0oooo00040?ooo`030000o`3o0000o`0000T0o`002`3oool60?l0
0140oooo0`000?lh0?ooo`<0003o2P3oool60?l002@0oooo0`000?l60?l000<0003o8P3oool60?l0
00T0oooo2@3o00040?ooo`<0003o5P3oool60?l000030?ooo`3o0000o`0000@0o`001@3oool20000
o`D0oooo00040?ooo`030000o`3o0000o`0000T0o`002`0000060?l0014000000`000?lh000000<0
003o2P0000060?l002@000000`000?l60?l000<0003o8P0000060?l000T000002@3o0004000000<0
003o5P0000060?l000030000003o0000o`0000@0o`001@0000020000o`D0oooo00040?ooo`80003o
103o00000`3oool0o`000?l000020?l000<0oooo00<000000?ooo`3oool01`3oool40?l000030000
003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0`000?l70?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0
oooo0`000?l30?ooo`030000003oool0oooo00D0oooo103o00020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`<0003o00<0oooo0?l0003o
00000P3o0000103oool0003o0000o`000?l90?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool40?l000/0oooo1`3o00050?ooo`<0003o3@3oool00`000000oooo0?ooo`070?oo
o`@0o`0000<000000?ooo`3oool0103o00060?ooo`80003o1@3oool000@0oooo0P000?l00`3oool0
o`000?l000030?ooo`80o`003`3oool20?l001<0oooo0`000?lh0?ooo`<0003o303oool20?l002H0
oooo0`000?l20?ooo`80o`000P3oool30000ob@0oooo0P3o000=0?ooo`80o`0000<0oooo0?l0003o
00001P3oool30000oaP0oooo0P3o00050?ooo`80o`001`3oool20000o`D0oooo00040?ooo`80003o
;03oool30000ocP0oooo0`000?ld0?ooo`<0003o1P3oool30000och0oooo0`000?lX0?ooo`80003o
1@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.95026 .05 Mdot
.01993 .05 Mdot
.94728 .05 Mdot
.58473 .05 Mdot
.01699 .05 Mdot
.80735 .05 Mdot
.12854 .05 Mdot
.05593 .05 Mdot
.27677 .05 Mdot
.17461 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo00080?ooo`<0o`00203o
ool20?l00180oooo0P3o000;0?ooo`80o`006`3oool20?l005<0oooo0P3o000l0?ooo`80o`009@3o
ool20?l001<0oooo00070?ooo`D0o`001P3oool40?l00100oooo103o00090?ooo`@0o`006@3oool4
0?l00540oooo103o000j0?ooo`@0o`008`3oool40?l00180oooo00040?ooo`80003o1`3o00040?oo
o`H0o`003P3oool60?l000L0oooo1P3o000G0?ooo`H0o`00603oool30000oc@0oooo1P3o00030?oo
o`<0003o<P3oool60?l000H0oooo0`000?lH0?ooo`H0o`002P3oool20000o`D0oooo00040?ooo`80
003o1`3o0004000000H0o`003P0000060?l000L000001P3o000G000000H0o`00600000030000oc@0
00001P3o0003000000<0003o<P0000060?l000H000000`000?lH000000H0o`002P0000020000o`D0
oooo00040?ooo`80003o00<0oooo0?l0003o00000`3o00060?ooo`@0o`002P3oool00`000000oooo
0?ooo`030?ooo`@0o`00103oool01@000000oooo0?ooo`3oool0003o00@0o`001@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo103o00040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool30000o`<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000?l0
o`000?l000020?l00080oooo00<000000?ooo`000?l00P000?l90?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`000080
o`001`3oool30000o`d0oooo00<000000?ooo`3oool02@3oool40?l000/0oooo0P000?l50?ooo`00
103oool20000o`80oooo0`3o00080?ooo`80o`004P3oool20?l000T0oooo0P000?l20?l001/0oooo
0P3o000J0?ooo`<0003o=03oool20000o`80o`001@3oool30000oc@0oooo0P3o00080?ooo`<0003o
6P3oool20?l000`0oooo0P000?l50?ooo`00103oool20000ob`0oooo0`000?lh0?ooo`<0003o=03o
ool30000o`H0oooo0`000?ln0?ooo`<0003o:03oool20000o`D0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.05 0.05 [
[0 .0375 -3 -9 ]
[0 .0375 3 0 ]
[.2 .0375 -9 -9 ]
[.2 .0375 9 0 ]
[.4 .0375 -9 -9 ]
[.4 .0375 9 0 ]
[.6 .0375 -9 -9 ]
[.6 .0375 9 0 ]
[.8 .0375 -9 -9 ]
[.8 .0375 9 0 ]
[1 .0375 -3 -9 ]
[1 .0375 3 0 ]
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .05 m
0 .05625 L
s
[(0)] 0 .0375 0 1 Mshowa
.2 .05 m
.2 .05625 L
s
[(0.2)] .2 .0375 0 1 Mshowa
.4 .05 m
.4 .05625 L
s
[(0.4)] .4 .0375 0 1 Mshowa
.6 .05 m
.6 .05625 L
s
[(0.6)] .6 .0375 0 1 Mshowa
.8 .05 m
.8 .05625 L
s
[(0.8)] .8 .0375 0 1 Mshowa
1 .05 m
1 .05625 L
s
[(1)] 1 .0375 0 1 Mshowa
.125 Mabswid
.05 .05 m
.05 .05375 L
s
.1 .05 m
.1 .05375 L
s
.15 .05 m
.15 .05375 L
s
.25 .05 m
.25 .05375 L
s
.3 .05 m
.3 .05375 L
s
.35 .05 m
.35 .05375 L
s
.45 .05 m
.45 .05375 L
s
.5 .05 m
.5 .05375 L
s
.55 .05 m
.55 .05375 L
s
.65 .05 m
.65 .05375 L
s
.7 .05 m
.7 .05375 L
s
.75 .05 m
.75 .05375 L
s
.85 .05 m
.85 .05375 L
s
.9 .05 m
.9 .05375 L
s
.95 .05 m
.95 .05375 L
s
.25 Mabswid
0 .05 m
1 .05 L
s
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
.5 Mabswid
0 .05 m
.00123 .05 L
.00236 .05 L
.00365 .05 L
.00488 .05 L
.00601 .05 L
.00706 .05 L
.00821 .05 L
.00942 .05 L
.01065 .05 L
.01196 .05 L
.0132 .05 L
.01434 .05 L
.01566 .05 L
.01641 .05 L
.01711 .05 L
.01839 .05 L
.01975 .05 L
.02043 .05 L
.02115 .05 L
.02245 .05 L
.02317 .05 L
.02384 .05 L
.02458 .05 L
.02537 .05 L
.02605 .05 L
.02679 .05 L
.02814 .05 L
.02945 .05 L
.03067 .05 L
.03184 .05 L
.03295 .05 L
.03416 .05 L
.03547 .05 L
.03676 .05 L
.03813 .05 L
.03929 .05 L
.04057 .05 L
.04131 .05 L
.042 .05 L
.04275 .05 L
.04355 .05 L
.0449 .05 L
.04566 .05 L
.04637 .05 L
.0477 .05 L
.04892 .05 L
.04959 .05 L
.05032 .05 L
.05165 .05 L
Mistroke
.05245 .05 L
.05321 .05 L
.05389 .05 L
.05462 .05 L
.05543 .05 L
.05627 .05 L
.057 .05 L
.05779 .05 L
.05854 .05 L
.05921 .05 L
.06 .05 L
.06074 .05 L
.06205 .05 L
.0628 .05 L
.06349 .05 L
.06471 .05 L
.06603 .05 L
.06727 .05 L
.06841 .05 L
.06967 .05 L
.07105 .05 L
.07175 .05 L
.07249 .05 L
.07383 .05 L
.07457 .05 L
.07525 .05 L
.076 .05 L
.07679 .05 L
.07812 .05 L
.07888 .05 L
.07959 .05 L
.0809 .05 L
.08211 .05 L
.08349 .05 L
.08481 .05 L
.086 .05 L
.08729 .05 L
.0885 .05 L
.08962 .05 L
.09085 .05 L
.0922 .05 L
.09289 .05 L
.09361 .05 L
.09493 .05 L
.09565 .05 L
.09632 .05 L
.09705 .05 L
.09783 .05 L
.09913 .05 L
.09987 .05 L
Mistroke
.10056 .05 L
.10185 .05 L
.10303 .05 L
.10439 .05 L
.10569 .05 L
.10691 .05 L
.10801 .05 L
.10928 .05 L
.11048 .05 L
.1116 .05 L
.11262 .05 L
.11375 .05 L
.11493 .05 L
.11613 .05 L
.11742 .05 L
.11864 .05 L
.11974 .05 L
.12104 .05 L
.12178 .05 L
.12245 .05 L
.1237 .05 L
.12502 .05 L
.12622 .05 L
.12753 .05 L
.12889 .05 L
.13016 .05 L
.13135 .05 L
.13244 .05 L
.13369 .05 L
.13487 .05 L
.13616 .05 L
.13752 .05 L
.13868 .05 L
.13996 .05 L
.14134 .05 L
.14211 .05 L
.14281 .05 L
.14418 .05 L
.14548 .05 L
.14669 .05 L
.14779 .05 L
.14906 .05 L
.15025 .05 L
.15136 .05 L
.15237 .05 L
.15349 .05 L
.15467 .05 L
.15586 .05 L
.15714 .05 L
.15835 .05 L
Mistroke
.15945 .05 L
.16074 .05 L
.16146 .05 L
.16214 .05 L
.16337 .05 L
.16468 .05 L
.16594 .05 L
.16732 .05 L
.16863 .05 L
.16984 .05 L
.17103 .05 L
.17212 .05 L
.17337 .05 L
.17456 .05 L
.17585 .05 L
.17721 .05 L
.17838 .05 L
.17966 .05 L
.18104 .05 L
.18181 .05 L
.18251 .05 L
.18388 .05 L
.18518 .05 L
.18628 .05 L
.1875 .05 L
.18877 .05 L
.18996 .05 L
.19107 .05 L
.19209 .05 L
.19321 .05 L
.19438 .05 L
.19558 .05 L
.19686 .05 L
.19807 .05 L
.19916 .05 L
.20045 .05 L
.20118 .05 L
.20185 .05 L
.20309 .05 L
.20439 .05 L
.20566 .05 L
.20705 .05 L
.20835 .05 L
.20957 .05 L
.21077 .05 L
.21186 .05 L
.21311 .05 L
.2143 .05 L
.21559 .05 L
.21696 .05 L
Mistroke
.21813 .05 L
.21941 .05 L
.22079 .05 L
.22157 .05 L
.22227 .05 L
.22364 .05 L
.22494 .05 L
.22604 .05 L
.22726 .05 L
.22853 .05 L
.22973 .05 L
.23084 .05 L
.23186 .05 L
.23297 .05 L
.23415 .05 L
.23535 .05 L
.23663 .05 L
.23784 .05 L
.23893 .05 L
.24023 .05 L
.24095 .05 L
.24163 .05 L
.24286 .05 L
.24416 .05 L
.24544 .05 L
.24683 .05 L
.24814 .05 L
.24935 .05 L
.25044 .05 L
.25165 .05 L
.25291 .05 L
.25409 .05 L
.25539 .05 L
.25676 .05 L
.25793 .05 L
.25922 .05 L
.2606 .05 L
.26137 .05 L
.26208 .05 L
.26345 .05 L
.26475 .05 L
.26586 .05 L
.26708 .05 L
.26835 .05 L
.26954 .05 L
.27066 .05 L
.27168 .05 L
.27286 .05 L
.27397 .05 L
.27518 .05 L
Mistroke
.27646 .05 L
.27767 .05 L
.27876 .05 L
.28005 .05 L
.28078 .05 L
.28145 .05 L
.28268 .05 L
.28399 .05 L
.28527 .05 L
.28599 .05 L
.28666 .05 L
.28789 .05 L
.28919 .05 L
.29036 .05 L
.29145 .05 L
.29265 .05 L
.29394 .05 L
.29524 .05 L
.29597 .05 L
.29665 .05 L
.29803 .05 L
.29881 .05 L
.29951 .05 L
.30077 .05 L
.30213 .05 L
.30342 .05 L
.30461 .05 L
.30572 .05 L
.30691 .05 L
.30804 .05 L
.30907 .05 L
.31027 .05 L
.31158 .05 L
.31282 .05 L
.31396 .05 L
.31526 .05 L
.31648 .05 L
.31758 .05 L
.31876 .05 L
.32005 .05 L
.32142 .05 L
.32259 .05 L
.32386 .05 L
.32524 .05 L
.32651 .05 L
.32718 .05 L
.32791 .05 L
.32867 .05 L
.32939 .05 L
.3307 .05 L
Mistroke
.3319 .05 L
.33329 .05 L
.33461 .05 L
.33578 .05 L
.33704 .05 L
.33822 .05 L
.33929 .05 L
.34055 .05 L
.34192 .05 L
.34321 .05 L
.3444 .05 L
.34567 .05 L
.34703 .05 L
.34831 .05 L
.34949 .05 L
.35086 .05 L
.35164 .05 L
.35236 .05 L
.35368 .05 L
.35434 .05 L
.35508 .05 L
.35579 .05 L
.35654 .05 L
.35788 .05 L
.35863 .05 L
.35932 .05 L
.36009 .05 L
.3609 .05 L
.36161 .05 L
.36238 .05 L
.3631 .05 L
.36377 .05 L
.36503 .05 L
.36637 .05 L
.36764 .05 L
.36902 .05 L
.37033 .05 L
.37154 .05 L
.37274 .05 L
.37383 .05 L
.37509 .05 L
.37627 .05 L
.37756 .05 L
.37893 .05 L
.3801 .05 L
.38138 .05 L
.38276 .05 L
.38353 .05 L
.38424 .05 L
.38561 .05 L
Mistroke
.38691 .05 L
.38801 .05 L
.38923 .05 L
.3905 .05 L
.39169 .05 L
.3928 .05 L
.39382 .05 L
.39494 .05 L
.39612 .05 L
.39732 .05 L
.3986 .05 L
.3998 .05 L
.4009 .05 L
.40219 .05 L
.40292 .05 L
.40359 .05 L
.40482 .05 L
.40613 .05 L
.4074 .05 L
.40879 .05 L
.4101 .05 L
.41132 .05 L
.41252 .05 L
.41361 .05 L
.41487 .05 L
.41605 .05 L
.41735 .05 L
.41872 .05 L
.41989 .05 L
.42117 .05 L
.42256 .05 L
.42333 .05 L
.42404 .05 L
.42541 .05 L
.4267 .05 L
.42781 .05 L
.42903 .05 L
.43031 .05 L
.4315 .05 L
.43261 .05 L
.43363 .05 L
.43481 .05 L
.43593 .05 L
.43713 .05 L
.43841 .05 L
.43962 .05 L
.44071 .05 L
.44201 .05 L
.44273 .05 L
.4434 .05 L
Mistroke
.44464 .05 L
.44594 .05 L
.44722 .05 L
.44794 .05 L
.44861 .05 L
.44984 .05 L
.45114 .05 L
.45231 .05 L
.4534 .05 L
.4546 .05 L
.45589 .05 L
.45718 .05 L
.45792 .05 L
.4586 .05 L
.45998 .05 L
.46075 .05 L
.46145 .05 L
.46271 .05 L
.46408 .05 L
.46537 .05 L
.46656 .05 L
.46766 .05 L
.46886 .05 L
.46998 .05 L
.47101 .05 L
.47221 .05 L
.47352 .05 L
.47476 .05 L
.4759 .05 L
.4772 .05 L
.47842 .05 L
.47952 .05 L
.4807 .05 L
.48199 .05 L
.48336 .05 L
.48453 .05 L
.4858 .05 L
.48718 .05 L
.48845 .05 L
.48911 .05 L
.48984 .05 L
.49061 .05 L
.49132 .05 L
.49264 .05 L
.49384 .05 L
.49516 .05 L
.49655 .05 L
.49772 .05 L
.49897 .05 L
.50015 .05 L
Mistroke
.50122 .05 L
.50248 .05 L
.50385 .05 L
.50514 .05 L
.50633 .05 L
.5076 .05 L
.50896 .05 L
.51024 .05 L
.51142 .05 L
.51279 .05 L
.51357 .05 L
.51429 .05 L
.5156 .05 L
.51627 .05 L
.51701 .05 L
.51772 .05 L
.51847 .05 L
.51981 .05 L
.52055 .05 L
.52125 .05 L
.52201 .05 L
.52283 .05 L
.52354 .05 L
.5243 .05 L
.52503 .05 L
.52569 .05 L
.52696 .05 L
.5283 .05 L
.52957 .05 L
.53095 .05 L
.53225 .05 L
.53347 .05 L
.53467 .05 L
.53575 .05 L
.53701 .05 L
.53819 .05 L
.53948 .05 L
.54085 .05 L
.54202 .05 L
.5433 .05 L
.54468 .05 L
.54545 .05 L
.54616 .05 L
.54753 .05 L
.54882 .05 L
.54993 .05 L
.55114 .05 L
.55241 .05 L
.55361 .05 L
.55472 .05 L
Mistroke
.55574 .05 L
.55685 .05 L
.55803 .05 L
.55923 .05 L
.56051 .05 L
.56172 .05 L
.56281 .05 L
.5641 .05 L
.56483 .05 L
.5655 .05 L
.56674 .05 L
.56804 .05 L
.56932 .05 L
.5707 .05 L
.57201 .05 L
.57323 .05 L
.57443 .05 L
.57552 .05 L
.57678 .05 L
.57796 .05 L
.57926 .05 L
.58063 .05 L
.5818 .05 L
.58308 .05 L
.58446 .05 L
.58524 .05 L
.58594 .05 L
.58731 .05 L
.58861 .05 L
.58971 .05 L
.59093 .05 L
.59221 .05 L
.5934 .05 L
.59451 .05 L
.59553 .05 L
.59671 .05 L
.59783 .05 L
.59903 .05 L
.60031 .05 L
.60152 .05 L
.60261 .05 L
.60391 .05 L
.60463 .05 L
.6053 .05 L
.60654 .05 L
.60784 .05 L
.60912 .05 L
.60984 .05 L
.61051 .05 L
.61174 .05 L
Mistroke
.61304 .05 L
.6142 .05 L
.61529 .05 L
.61649 .05 L
.61778 .05 L
.61908 .05 L
.61981 .05 L
.62049 .05 L
.62187 .05 L
.62264 .05 L
.62335 .05 L
.6246 .05 L
.62597 .05 L
.62726 .05 L
.62845 .05 L
.62955 .05 L
.63075 .05 L
.63187 .05 L
.6329 .05 L
.6341 .05 L
.63541 .05 L
.63665 .05 L
.63779 .05 L
.63909 .05 L
.64031 .05 L
.6414 .05 L
.64259 .05 L
.64388 .05 L
.64525 .05 L
.64641 .05 L
.64769 .05 L
.64907 .05 L
.65034 .05 L
.651 .05 L
.65173 .05 L
.65249 .05 L
.65321 .05 L
.65452 .05 L
.65572 .05 L
.65704 .05 L
.65843 .05 L
.6596 .05 L
.66085 .05 L
.66203 .05 L
.6631 .05 L
.66436 .05 L
.66573 .05 L
.66702 .05 L
.66821 .05 L
.66947 .05 L
Mistroke
.67083 .05 L
.67212 .05 L
.67329 .05 L
.67467 .05 L
.67544 .05 L
.67616 .05 L
.67748 .05 L
.67815 .05 L
.67888 .05 L
.67959 .05 L
.68034 .05 L
.68168 .05 L
.68243 .05 L
.68312 .05 L
.68389 .05 L
.6847 .05 L
.68541 .05 L
.68618 .05 L
.6869 .05 L
.68757 .05 L
.68883 .05 L
.69018 .05 L
.69144 .05 L
.69282 .05 L
.69413 .05 L
.69534 .05 L
.69654 .05 L
.69762 .05 L
.69888 .05 L
.70006 .05 L
.70135 .05 L
.70272 .05 L
.70388 .05 L
.70517 .05 L
.70654 .05 L
.70732 .05 L
.70802 .05 L
.70939 .05 L
.71069 .05 L
.71179 .05 L
.71301 .05 L
.71428 .05 L
.71547 .05 L
.71658 .05 L
.7176 .05 L
.71872 .05 L
.71989 .05 L
.72109 .05 L
.72237 .05 L
.72358 .05 L
Mistroke
.72468 .05 L
.72597 .05 L
.72669 .05 L
.72737 .05 L
.7286 .05 L
.72991 .05 L
.73118 .05 L
.73256 .05 L
.73387 .05 L
.73508 .05 L
.73629 .05 L
.73738 .05 L
.73863 .05 L
.73982 .05 L
.74111 .05 L
.74248 .05 L
.74365 .05 L
.74493 .05 L
.74631 .05 L
.74709 .05 L
.74779 .05 L
.74916 .05 L
.75046 .05 L
.75157 .05 L
.75279 .05 L
.75406 .05 L
.75525 .05 L
.75636 .05 L
.75738 .05 L
.7585 .05 L
.75968 .05 L
.76088 .05 L
.76216 .05 L
.76337 .05 L
.76446 .05 L
.76575 .05 L
.76648 .05 L
.76715 .05 L
.76839 .05 L
.76969 .05 L
.77097 .05 L
.77169 .05 L
.77236 .05 L
.77358 .05 L
.77489 .05 L
.77605 .05 L
.77714 .05 L
.77834 .05 L
.77963 .05 L
.78092 .05 L
Mistroke
.78165 .05 L
.78233 .05 L
.78371 .05 L
.78448 .05 L
.78519 .05 L
.78644 .05 L
.78781 .05 L
.7891 .05 L
.79029 .05 L
.79139 .05 L
.79258 .05 L
.79371 .05 L
.79473 .05 L
.79593 .05 L
.79724 .05 L
.79848 .05 L
.79963 .05 L
.80093 .05 L
.80214 .05 L
.80324 .05 L
.80442 .05 L
.80572 .05 L
.80708 .05 L
.80825 .05 L
.80953 .05 L
.8109 .05 L
.81217 .05 L
.81283 .05 L
.81356 .05 L
.81432 .05 L
.81504 .05 L
.81635 .05 L
.81755 .05 L
.81887 .05 L
.82026 .05 L
.82143 .05 L
.82268 .05 L
.82386 .05 L
.82493 .05 L
.82619 .05 L
.82755 .05 L
.82884 .05 L
.83003 .05 L
.8313 .05 L
.83266 .05 L
.83394 .05 L
.83512 .05 L
.83649 .05 L
.83727 .05 L
.83798 .05 L
Mistroke
.8393 .05 L
.84004 .05 L
.84071 .05 L
.84142 .05 L
.84216 .05 L
.8435 .05 L
.84425 .05 L
.84495 .05 L
.84571 .05 L
.84653 .05 L
.84723 .05 L
.848 .05 L
.84872 .05 L
.84939 .05 L
.85066 .05 L
.852 .05 L
.85326 .05 L
.85464 .05 L
.85595 .05 L
.85716 .05 L
.85835 .05 L
.85944 .05 L
.86069 .05 L
.86188 .05 L
.86317 .05 L
.86453 .05 L
.8657 .05 L
.86698 .05 L
.86836 .05 L
.86913 .05 L
.86984 .05 L
.87121 .05 L
.8725 .05 L
.8736 .05 L
.87482 .05 L
.87609 .05 L
.87728 .05 L
.87839 .05 L
.87941 .05 L
.88053 .05 L
.8817 .05 L
.8829 .05 L
.88418 .05 L
.88539 .05 L
.88649 .05 L
.88778 .05 L
.8885 .05 L
.88918 .05 L
.89041 .05 L
.89172 .05 L
Mistroke
.89299 .05 L
.89437 .05 L
.89568 .05 L
.89689 .05 L
.89809 .05 L
.89918 .05 L
.90044 .05 L
.90162 .05 L
.90292 .05 L
.90428 .05 L
.90545 .05 L
.90673 .05 L
.90812 .05 L
.90889 .05 L
.90959 .05 L
.91096 .05 L
.91226 .05 L
.91337 .05 L
.91458 .05 L
.91586 .05 L
.91705 .05 L
.91816 .05 L
.91918 .05 L
.9203 .05 L
.92148 .05 L
.92268 .05 L
.92396 .05 L
.92516 .05 L
.92626 .05 L
.92755 .05 L
.92828 .05 L
.92895 .05 L
.93018 .05 L
.93149 .05 L
.93276 .05 L
.93348 .05 L
.93415 .05 L
.93538 .05 L
.93668 .05 L
.93784 .05 L
.93893 .05 L
.94013 .05 L
.94142 .05 L
.94271 .05 L
.94344 .05 L
.94412 .05 L
.9455 .05 L
.94627 .05 L
.94697 .05 L
.94823 .05 L
Mistroke
.9496 .05 L
.95089 .05 L
.95207 .05 L
.95318 .05 L
.95437 .05 L
.95549 .05 L
.95652 .05 L
.95772 .05 L
.95903 .05 L
.96027 .05 L
.96141 .05 L
.96271 .05 L
.96393 .05 L
.96502 .05 L
.96621 .05 L
.9675 .05 L
.96887 .05 L
.97003 .05 L
.97131 .05 L
.97224 .05 L
.9731 .05 L
.97404 .05 L
.97503 .05 L
.9759 .05 L
.97671 .05 L
.9776 .05 L
.97856 .05 L
.97936 .05 L
.98024 .05 L
.98115 .05 L
.982 .05 L
.9828 .05 L
.98353 .05 L
.98437 .05 L
.98516 .05 L
.98602 .05 L
.98696 .05 L
.98795 .05 L
.98887 .05 L
.98973 .05 L
.99051 .05 L
.99142 .05 L
.99228 .05 L
.99321 .05 L
.9942 .05 L
.99513 .05 L
.99598 .05 L
.99697 .05 L
.99805 .05 L
.99907 .05 L
Mistroke
1 .05 L
Mfstroke
0 0 1 r
3 Mabswid
0 .05 m
0 .06 L
s
.16967 .05 m
.16967 .06 L
s
.38057 .05 m
.38057 .06 L
s
.57895 .05 m
.57895 .06 L
s
.61057 .05 m
.61057 .06 L
s
.8477 .05 m
.8477 .06 L
s
1 .05 m
1 .06 L
s
1 0 0 r
6 Mabswid
.87106 .05 Mdot
.73533 .05 Mdot
.78411 .05 Mdot
.96722 .05 Mdot
.84087 .05 Mdot
.79346 .05 Mdot
.35189 .05 Mdot
.99977 .05 Mdot
.82973 .05 Mdot
.97648 .05 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 28.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000072000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`000`3oool200000300oooo0P0000040?ooo`8000000`3oool4000002P0
oooo0P0000040?ooo`8000001@3oool3000002P0oooo0P0000040?ooo`8000000`3oool3000002T0
oooo0P0000040?ooo`800000103oool2000002l0oooo1@0000030?ooo`000P3oool010000000oooo
0?ooo`00000^0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000<03oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00
00080?ooo`D000009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000`0?ooo`030000003oool0
oooo00<0oooo00020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool010000000oooo0?ooo`0000080?ooo`<00000:03oool010000000oooo0?ooo`000009
0?ooo`800000<@3oool00`000000oooo0?ooo`030?ooo`000P3oool010000000oooo0?ooo`00000^
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000002P0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000<03o
ool00`000000oooo0?ooo`030?ooo`000`3oool200000300oooo0P00000:0?ooo`800000:@3oool2
000000/0oooo0P00000Y0?ooo`8000002P3oool3000002P0oooo0P00000:0?ooo`800000<03oool2
000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo001U0?ooo`80o`00J@3o
ool20?l000/0oooo0P3o00000`3oool0o`000?l000080?ooo`80o`0000<0oooo0?l0003o00001P3o
ool20?l001T0oooo0P3o00000`3oool0o`000?l000040?ooo`80o`001@3oool006@0oooo103o001W
0?ooo`@0o`002@3oool70?l000H0oooo1`3o00040?ooo`@0o`005`3oool70?l00080oooo0`3o0005
0?ooo`00103oool20000ob`0oooo0`000?l^0?ooo`H0o`00103oool30000oc@0oooo0`000?l60?oo
o`<0003o7P3oool60?l000L0oooo2@3o00040?ooo`T0o`000P3oool60?l001D0oooo3@3o00050?oo
o`00103oool20000ob`000000`000?l^000000H0o`00100000030000oc@000000`000?l6000000<0
003o7P0000060?l000L000002@3o0004000000T0o`000P0000060?l001D000003@3o00050?ooo`00
103oool20000o``0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo0?ooo`<0003o1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool40?l000D0oooo0`000?l30?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo0`000?l40?ooo`030000003oool0003o0080003o2@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00D0oooo103o00000`3oool000000?ooo`060?ooo`L0o`001P3oool70?l00004
0000o`3oool0oooo0?ooo`@0o`001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0o`000P3oool30?l000D0oooo00040?ooo`80003o;03oool30000oc00oooo0P3o00060?ooo`<0
003o=03oool30000o`H0oooo0`000?lP0?ooo`80o`002`3oool20?l000030?ooo`3o0000o`0000P0
oooo0P3o00000`3oool0o`000?l000020000o`@0oooo0P3o000I0?ooo`80o`0000<0oooo0?l0003o
0000103oool20?l000D0oooo00040?ooo`80003o;03oool30000ocP0oooo0`000?ld0?ooo`<0003o
1P3oool30000och0oooo0`000?lX0?ooo`80003o1@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {27.75, 0}} -> {-0.0171223, -1.00001, \
0.00360364, 0.0720728}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verteilung \[UDoubleDot]ber viele Zufallsexperimente", "Subsection"],

Cell[BoxData[
    \(\(\(\ \)\(SeedRandom[1]\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(rand\)\(=\)\(Table[Random[], {6}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
      0.12463419022903224`, 0.9345372830959425`, 
      0.6002520340808316`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probDist = rand/Apply[Plus, rand]\)], "Input"],

Cell[BoxData[
    \({0.1696705704267232`, 0.21090429301674657`, 0.1983717253211976`, 
      0.03162402528244657`, 0.23712458526593577`, 
      0.15230480068695026`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Do[{X = Random[], \ 
        val[k]\  = \ \(Position[Sort[Append[cumDist, X]], X]\)[\([1, 
                1]\)]\  - 1}, {k, 1, 10}]\), "\[IndentingNewLine]", 
    \(valTab\  = \ Table[val[k], {k, 1, 10}]\)}], "Input"],

Cell[BoxData[
    \({5, 6, 1, 3, 5, 5, 4, 2, 5, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Histogram[valTab, \ 
        HistogramCategories \[Rule] {0, 1, 2, 3, 4, 5, 6, 7}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.166667 0.0147151 0.147151 [
[.16667 .00222 -3 -9 ]
[.16667 .00222 3 0 ]
[.33333 .00222 -3 -9 ]
[.33333 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.66667 .00222 -3 -9 ]
[.66667 .00222 3 0 ]
[.83333 .00222 -3 -9 ]
[.83333 .00222 3 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .01472 m
.16667 .02097 L
s
[(2)] .16667 .00222 0 1 Mshowa
.33333 .01472 m
.33333 .02097 L
s
[(3)] .33333 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.66667 .01472 m
.66667 .02097 L
s
[(5)] .66667 .00222 0 1 Mshowa
.83333 .01472 m
.83333 .02097 L
s
[(6)] .83333 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(7)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .16187 m
.00625 .16187 L
s
[(1)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(2)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(3)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(4)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .16187 L
.16667 .16187 L
.16667 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .16187 L
.16667 .16187 L
.16667 .01472 L
0 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .16187 L
.33333 .16187 L
.33333 .01472 L
F
0 g
.16667 .01472 m
.16667 .16187 L
.33333 .16187 L
.33333 .01472 L
.16667 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .30902 L
.5 .30902 L
.5 .01472 L
F
0 g
.33333 .01472 m
.33333 .30902 L
.5 .30902 L
.5 .01472 L
.33333 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .16187 L
.66667 .16187 L
.66667 .01472 L
F
0 g
.5 .01472 m
.5 .16187 L
.66667 .16187 L
.66667 .01472 L
.5 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
F
0 g
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
.66667 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .16187 L
1 .16187 L
1 .01472 L
F
0 g
.83333 .01472 m
.83333 .16187 L
1 .16187 L
1 .01472 L
.83333 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00=P3oool4000002X0oooo0P00000/0?ooo`<00000:P3oool2000002X0oooo0`00000/0?oo
o`030000003oool0oooo00<0oooo000f0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3o
ool00000;03oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002T0oooo00@00000
0?ooo`3oool00000:`3oool00`000000oooo0?ooo`030?ooo`00=`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo02P0oooo1@00000/0?ooo`030000003oool0oooo02L0oooo00@00000
0?ooo`3oool00000:`3oool00`000000oooo0?ooo`030?ooo`00>03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000:`3oool2000002X0oooo0`00
000]0?ooo`030000003oool0oooo0080oooo000f0?ooo`040000003oool0oooo000002T0oooo00@0
00000?ooo`3oool00000:P3oool00`000000oooo0000000[0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`0000040?ooo`00=`3oool2000002/0oooo
0P00000/0?ooo`800000:`3oool3000002X0oooo0`00000Y0?ooo`@00000103oool00?l0oooo8@3o
ool000X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`002P3oool00`000000oooo0?ooo`3o0?oo
oa@0oooo000:0?ooo`030000003oool0oooo0?l0oooo503oool000X0oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`002P3ooooo0000018000001@3oool000X0oooo00<000000?l0003o0000:`3o0000
0`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o0000
0`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool0
00X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo
00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<00000
0?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o
0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o
0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3o
ool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3o
ool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0
oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<0
00000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<0
00000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<0
00000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0
003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0
003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?oo
o`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l00003
0000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l00003
0000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000
:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000
:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool0
0`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o
0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o
0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o0000
0`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o0000
0`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool0
00X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo
00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<00000
0?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o
0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o
0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3o
ool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3o
ool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0
oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<0
00000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<0
00000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<0
00000?ooo`3oool00`3oool000X0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000X0oooo00<000000?l0
003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0
003o0000:`3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?oo
o`3oool00`3oool00080oooo1@0000030?ooo`030000003o0000o`0002/0o`0000<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002/0o`0000<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo00<0oooo00040?ooo`030000
003oool0oooo00<0oooo00<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?l0003o0000:`3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool00`3o
oomL000002`0o`00;`00000/0?l002h000001@3oool000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool0
0`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z0?l000030000003oool0oooo
02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`000`3oool2000000D0
oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z0?l000030000003oool0oooo02/0
oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo
0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0o`0000<0
00000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z
0?l000030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`
0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?oo
o`3oool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`80
0000F@3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02/0oooo00<000000?l0003o
0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000
003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l000030000
003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0oooo00<000000?l0003o0000:P3o
00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03o
ool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z0?l000030000003oool0
oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`00
0000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0
oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo
0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<0
00000?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:
0?ooo`800000F@3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02/0oooo00<00000
0?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?oo
o`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l0
00030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0oooo00<000000?l0003o
0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3o
ool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z0?l000030000
003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3o
ool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0
oooo05P0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000
o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`00
0000o`000?l0000Z0?l000030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300
oooo000:0?ooo`800000F@3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02/0oooo
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?oo
o`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000o`000?l0
000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0oooo00<00000
0?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0o`0000<00000
0?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000Z0?l0
00030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?oo
o`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3o
ool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000
003oool0oooo05P0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000
003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03o
ool00`000000o`000?l0000Z0?l000030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o
00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000
o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo0300oooo000:0?ooo`800000F@3oool00`000000o`000?l0000Z0?l000030000003oool0oooo
02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000
oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0:`3oool00`000000
o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo05P0oooo
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002X0o`00
00<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0
000Z0?l000030000003oool0oooo02/0oooo00<000000?l0003o0000:P3o00000`000000oooo0?oo
o`0`0?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<00000
0?ooo`3oool0:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?oo
o`030000003oool0oooo05P0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?oo
o`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool00080oooo100000040?ooo`03
0000003oool0oooo05P0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0[0?ooo`03
0000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool00080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0
:`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo00030?ooo`030000003o
ool0oooo00@0oooo0`00001H0?ooobh00000;@3oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo0300oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/`3oool0
0`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo00020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo0300oooo00030?ooo`8000001@3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`00
02X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000
o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?oo
o`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<00000
0?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?oo
o`800000]03oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`03
0000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`00
2P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0
<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o0000
0`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`00
02X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000
o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool200000;@0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c
0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?oo
o`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`03
0000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`00
2P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0
<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o0000
0`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`00
02X0o`0000<000000?ooo`3oool0<03oool000X0oooo0P00002d0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c
0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?oo
o`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`03
0000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`00
2P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0
<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo0300oooo000:0?ooo`800000]03oool00`000000o`000?l0000Z0?l000030000003oool0
oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c
0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000<0oooo0P0000050?oo
o`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?oo
o`000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0;<0oooo00<000000?l0
003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`00103oool00`000000oooo0?ooo`030?ooo`<0
0000/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo00050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000
003oool0oooo0300oooo00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo00030?ooo`8000001@3o
ool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03o
ool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`800000]03oool00`000000o`000?l0
000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<00000
0?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?oo
o`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3o
ool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000
003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3o
ool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03o
ool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`0`0?ooo`002P3oool200000;@0oooo00<000000?l0003o0000:P3o00000`000000
oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`00
00<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0
000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<00000
0?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?oo
o`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3o
ool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000
003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3o
ool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03o
ool000X0oooo0P00002d0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool0
00X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo
0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000
oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`00
00<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0
000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<00000
0?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?oo
o`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3o
ool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`800000
]03oool00`000000o`000?l0000Z0?l000030000003oool0oooo0300oooo000:0?ooo`030000003o
ool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`002P3oool0
0`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0<03oool0
00X0oooo00<000000?ooo`3oool0/`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo
0300oooo000:0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000
oooo0?ooo`0`0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`030000003o0000o`0002X0o`00
00<000000?ooo`3oool0<03oool000@0oooo0`0000030?ooo`030000003oool0oooo0;<0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0`0?ooo`001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0;<0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0`
0?ooo`000P3oool5000000<0oooo0`00002c0?ooobh00000<P3oool00080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?oooa@0oooo00030?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00103oool2000000@0oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooa@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.762732, -0.30988, \
0.0220673, 0.024994}}]
}, Open  ]],

Cell[BoxData[
    \(\(\(\ \)\(SeedRandom[1]\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(rand\)\(=\)\(Table[Random[], {6}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
      0.12463419022903224`, 0.9345372830959425`, 
      0.6002520340808316`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probDist = rand/Apply[Plus, rand]\)], "Input"],

Cell[BoxData[
    \({0.1696705704267232`, 0.21090429301674657`, 0.1983717253211976`, 
      0.03162402528244657`, 0.23712458526593577`, 
      0.15230480068695026`}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Do[{X = Random[], \ 
        val[k]\  = \ \(Position[Sort[Append[cumDist, X]], X]\)[\([1, 
                1]\)]\  - 1}, {k, 1, 100}]\), "\[IndentingNewLine]", 
    \(\(valTab\  = \ Table[val[k], {k, 1, 100}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Histogram[valTab, \ 
        HistogramCategories \[Rule] {0, 1, 2, 3, 4, 5, 6, 7}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.166667 0.0147151 0.0226386 [
[.16667 .00222 -3 -9 ]
[.16667 .00222 3 0 ]
[.33333 .00222 -3 -9 ]
[.33333 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.66667 .00222 -3 -9 ]
[.66667 .00222 3 0 ]
[.83333 .00222 -3 -9 ]
[.83333 .00222 3 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .12791 -6 -4.5 ]
[-0.0125 .12791 0 4.5 ]
[-0.0125 .2411 -12 -4.5 ]
[-0.0125 .2411 0 4.5 ]
[-0.0125 .35429 -12 -4.5 ]
[-0.0125 .35429 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .58068 -12 -4.5 ]
[-0.0125 .58068 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .01472 m
.16667 .02097 L
s
[(2)] .16667 .00222 0 1 Mshowa
.33333 .01472 m
.33333 .02097 L
s
[(3)] .33333 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.66667 .01472 m
.66667 .02097 L
s
[(5)] .66667 .00222 0 1 Mshowa
.83333 .01472 m
.83333 .02097 L
s
[(6)] .83333 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(7)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .12791 m
.00625 .12791 L
s
[(5)] -0.0125 .12791 1 0 Mshowa
0 .2411 m
.00625 .2411 L
s
[(10)] -0.0125 .2411 1 0 Mshowa
0 .35429 m
.00625 .35429 L
s
[(15)] -0.0125 .35429 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(20)] -0.0125 .46749 1 0 Mshowa
0 .58068 m
.00625 .58068 L
s
[(25)] -0.0125 .58068 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .39957 L
.16667 .39957 L
.16667 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .39957 L
.16667 .39957 L
.16667 .01472 L
0 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .5354 L
.33333 .5354 L
.33333 .01472 L
F
0 g
.16667 .01472 m
.16667 .5354 L
.33333 .5354 L
.33333 .01472 L
.16667 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .2411 L
.5 .2411 L
.5 .01472 L
F
0 g
.33333 .01472 m
.33333 .2411 L
.5 .2411 L
.5 .01472 L
.33333 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .12791 L
.66667 .12791 L
.66667 .01472 L
F
0 g
.5 .01472 m
.5 .12791 L
.66667 .12791 L
.66667 .01472 L
.5 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
F
0 g
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
.66667 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .44485 L
1 .44485 L
1 .01472 L
F
0 g
.83333 .01472 m
.83333 .44485 L
1 .44485 L
1 .01472 L
.83333 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00>P3oool4000002T0oooo0P00000/0?ooo`<00000:@3oool2000002X0
oooo0`00000/0?ooo`030000003oool0oooo0040oooo000j0?ooo`030000003oool0oooo02T0oooo
00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo0000
02T0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`010?ooo`00>`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo1@00000[0?ooo`030000003oool0oooo
02L0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`010?ooo`00?03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000:P3oool2
000002X0oooo0`00000]0?ooo`4000000@3oool10?ooo`00>P3oool010000000oooo0?ooo`00000X
0?ooo`040000003oool0oooo000002X0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000000P3oool003/0oooo0P00
000Z0?ooo`800000;03oool2000002X0oooo0`00000Z0?ooo`<00000:@3oool400000080oooo003o
0?ooob40oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003o
ool0oooo0?l0oooo3`3oool000l0ooooo`00000?000000<0oooo000?0?ooo`030000003o0000o`00
02X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo
0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<00000
0?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000
003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o
00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000
o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0
oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0
o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040
oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`00
0?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<0
00000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<0
00000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?
0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z
0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0
003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0
003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l00003
0000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l00003
0000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000
:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000
:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o
0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o
0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o0000
0`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o0000
0`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`00
02X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo
0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000
o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<00000
0?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l0
00030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:@3o00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000
003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo0040oooo00080?ooo`8000001@3oool00`000000o`000?l0000Z0?l000030000003o
0000o`0002T0o`0000<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003o
0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`001`3oool0
10000000oooo0?ooo`0000040?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o
00000`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o
00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000:0?ooo`030000003oool0
oooo0080oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003o0000
o`0002X0o`00;P00000/0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool0
00P0oooo0P0000050?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo0040oooo00080?ooo`030000003oool0oooo00@0
oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003o0000o`0002X0
o`0000<000000?ooo`3oool0:P3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?ooo`3oool00@3oool000P0oooo0`0000040?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<00000
0?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000
003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o
00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o
00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000
o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0
oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0
oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0
o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0
oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040
oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`00
0?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`00
0?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<0
00000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<0
00000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?
0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z
0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z
0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0
003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0
003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l00003
0000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l00003
0000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000
:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000
:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o
0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003o
ool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o0000
0`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o0000
0`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`00
02X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo
02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo
0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<00000
0?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo02X0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o
0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo00000`3oool00000
0000000300000080oooo0P0000050?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000
:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo00<000000?l0003o0000
:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo00030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Z0?l000030000003oool0oooo02X0oooo
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003o0000o`0002X0o`0000<000000?l0003o0000:@3o000^000002`0oooo00<000000?l0003o0000
:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo00030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000o`000?l0000Z0?l000030000
003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool00080oooo0P0000040?ooo`8000001@3o
ool00`000000o`000?l0000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3o
ool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3o
ool000l0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0
oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0
oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002T0
o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0
o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000:P3o00000`000000o`00
0?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`00
0?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0000Z
0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z
0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0
003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0
003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`03
0000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`03
0000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`00
3`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0
E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool0
0@3oool000l0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003o
ool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o0000
0`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0000Z0?l000030000003o0000o`00
02T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0
000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<00000
0?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?oo
o`003`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3o
ool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3o
ool00@3oool000l0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000
003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o
00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0000Z0?l000030000003o0000
o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000
o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000:P3o00000`00
0000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`00
0000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0
o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`00
0?l0000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`00
0?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000030?ooo`00
0000000000<000000P3oool2000000D0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0
000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0
000Z0?l000030000003oool0oooo0040oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o
00000`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0
oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0
oooo0040oooo00030?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003o0000o`00
02X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`00
02X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo00020?ooo`800000103oool3000000@0oooo
00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo
00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo
000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?oo
o`010?ooo`003`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002T0o`0000<00000
0?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<00000
0?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l0
00030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l0
00030000003oool0oooo0040oooo000?0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o
0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000o`000?l0000Z0?l000030000
003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000
003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?l0003o0000:P3o
00000`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o
00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003o0000
o`0002X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000
o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`00
0000o`000?l0000Z0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`00
0000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0
oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Y0?l000030000003oool0oooo05L0
oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040
oooo000?0?ooobh00000:`3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<00000
0?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<00000
0?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?oo
o`030000003oool0oooo02X0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?oo
o`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?oo
o`003`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3o
ool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3o
ool00@3oool000l0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000
003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000
003oool0oooo0040oooo000?0?ooo`800000:`3oool00`000000o`000?l0000Y0?l000030000003o
ool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000o`000?l0000Z0?l000030000003o
ool0oooo0040oooo000?0?ooo`030000003oool0oooo02X0oooo00<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?l0003o0000:P3o0000
0`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`00
02T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o0000o`00
02X0o`0000<000000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0:P3oool00`000000
o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000
o`000?l0000Z0?l000030000003oool0oooo0040oooo000?0?ooo`030000003oool0oooo02X0oooo
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`00
00<000000?l0003o0000:P3o00000`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0
000Z0?l000030000003o0000o`0002X0o`0000<000000?ooo`3oool00@3oool000l0oooo0P00000[
0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z
0?l002h000000`3oool000l0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l0
00030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?oo
o`003`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3o
ool0E`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02h0oooo000?0?ooo`030000
003oool0oooo02X0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000
003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool000030?ooo`0000000000008000000`3o
ool2000000D0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000003o
ool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`0000<0oooo
0000003oool0103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02X0oooo00<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<0
00000?ooo`3oool0;P3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`<00000:P3oool00`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo02h0oooo00001@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0
E`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02h0oooo00020?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000003o
ool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`003`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool0
0`000000o`000?l0000Z0?l000030000003oool0oooo02h0oooo000?0?ooo`030000003oool0oooo
02X0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`00
02X0o`0000<000000?ooo`3oool0;P3oool000l0oooo0P00000[0?ooo`030000003o0000o`0002T0
o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003oool0oooo02h0
oooo000?0?ooo`030000003oool0oooo02X0oooo00<000000?l0003o0000:@3o00000`000000oooo
0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool000l0oooo00<0
00000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z
0?l000030000003oool0oooo02h0oooo000?0?ooo`030000003oool0oooo02X0oooo00<000000?l0
003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?oo
o`3oool0;P3oool000l0oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l00003
0000003oool0oooo05L0oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`00
3`3oool2000002/0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`1G0?ooo`030000
003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool000l0oooo00<000000?ooo`3oool0:P3o
ool00`000000o`000?l0000Y0?l000030000003oool0oooo05L0oooo00<000000?l0003o0000:P3o
00000`000000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o0000
o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo02h0oooo000?0?ooo`030000003oool0oooo02X0oooo00<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`1G0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool000l0
oooo00<000000?ooo`3oool0:P3oool00`000000o`000?l0000Y0?l000030000003oool0oooo05L0
oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0E`3oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo02h0oooo000?0?ooo`800000:`3oool]000005T0oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo0?ooo`2`
0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool000l0oooo00<000000?oo
o`3oool0/03oool00`000000o`000?l0000Z0?l000030000003oool0oooo02h0oooo000?0?ooo`03
0000003oool0oooo0;00oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`00
3`3oool00`000000oooo0?ooo`2`0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0
;P3oool000l0oooo00<000000?ooo`3oool0/03oool00`000000o`000?l0000Z0?l000030000003o
ool0oooo02h0oooo000?0?ooo`800000/@3oool00`000000o`000?l0000Z0?l000030000003oool0
oooo02h0oooo000?0?ooo`030000003oool0oooo0;00oooo00<000000?l0003o0000:P3o00000`00
0000oooo0?ooo`0^0?ooo`003`3oool00`000000oooo0?ooo`2`0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0;P3oool000l0oooo00<000000?ooo`3oool0/03oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo02h0oooo00000`3oool0000000000002000000<0oooo0P00
00050?ooo`030000003oool0oooo0;00oooo00<000000?l0003o0000:P3o00000`000000oooo0?oo
o`0^0?ooo`0000<0oooo0000003oool0103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0;00oooo00<000000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00002`0?ooo`030000003o0000
o`0002X0o`0000<000000?ooo`3oool0;P3oool000<0oooo00<000000?ooo`3oool00P3oool20000
00D0oooo00<000000?ooo`3oool0/03oool00`000000o`000?l0000Z0?l000030000003oool0oooo
02h0oooo00001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2`0?ooo`030000003o0000o`0002X0o`0000<000000?ooo`3oool0;P3oool00080
oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`2`0?ooo`030000003o0000o`0002X0
o`0000<000000?ooo`3oool0;P3oool000l0oooo00<000000?ooo`3oool0/03oool00`000000o`00
0?l0000Z0?l000030000003oool0oooo02h0oooo000?0?ooo`030000003oool0oooo0;00oooo00<0
00000?l0003o0000:P3o00000`000000oooo0?ooo`0^0?ooo`003`3oool200000;40oooo;P00000`
0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0
oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.656953, -2.2379, \
0.0223347, 0.16443}}]
}, Open  ]],

Cell[BoxData[
    \(\(\(\ \)\(SeedRandom[1]\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(rand\)\(=\)\(Table[Random[], {6}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({0.6686926778600345`, 0.8311998722869463`, 0.7818074748209513`, 
      0.12463419022903224`, 0.9345372830959425`, 
      0.6002520340808316`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probDist = rand/Apply[Plus, rand]\)], "Input"],

Cell[BoxData[
    \({0.1696705704267232`, 0.21090429301674657`, 0.1983717253211976`, 
      0.03162402528244657`, 0.23712458526593577`, 
      0.15230480068695026`}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Do[{X = Random[], \ 
        val[k]\  = \ \(Position[Sort[Append[cumDist, X]], X]\)[\([1, 
                1]\)]\  - 1}, {k, 1, 1000}]\), "\[IndentingNewLine]", 
    \(\(valTab\  = \ Table[val[k], {k, 1, 1000}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Histogram[valTab, \ 
        HistogramCategories \[Rule] {0, 1, 2, 3, 4, 5, 6, 7}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.166667 0.0147151 0.0025047 [
[.16667 .00222 -3 -9 ]
[.16667 .00222 3 0 ]
[.33333 .00222 -3 -9 ]
[.33333 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.66667 .00222 -3 -9 ]
[.66667 .00222 3 0 ]
[.83333 .00222 -3 -9 ]
[.83333 .00222 3 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .13995 -12 -4.5 ]
[-0.0125 .13995 0 4.5 ]
[-0.0125 .26518 -18 -4.5 ]
[-0.0125 .26518 0 4.5 ]
[-0.0125 .39042 -18 -4.5 ]
[-0.0125 .39042 0 4.5 ]
[-0.0125 .51565 -18 -4.5 ]
[-0.0125 .51565 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .01472 m
.16667 .02097 L
s
[(2)] .16667 .00222 0 1 Mshowa
.33333 .01472 m
.33333 .02097 L
s
[(3)] .33333 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.66667 .01472 m
.66667 .02097 L
s
[(5)] .66667 .00222 0 1 Mshowa
.83333 .01472 m
.83333 .02097 L
s
[(6)] .83333 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(7)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .13995 m
.00625 .13995 L
s
[(50)] -0.0125 .13995 1 0 Mshowa
0 .26518 m
.00625 .26518 L
s
[(100)] -0.0125 .26518 1 0 Mshowa
0 .39042 m
.00625 .39042 L
s
[(150)] -0.0125 .39042 1 0 Mshowa
0 .51565 m
.00625 .51565 L
s
[(200)] -0.0125 .51565 1 0 Mshowa
.125 Mabswid
0 .03976 m
.00375 .03976 L
s
0 .06481 m
.00375 .06481 L
s
0 .08986 m
.00375 .08986 L
s
0 .1149 m
.00375 .1149 L
s
0 .165 m
.00375 .165 L
s
0 .19004 m
.00375 .19004 L
s
0 .21509 m
.00375 .21509 L
s
0 .24014 m
.00375 .24014 L
s
0 .29023 m
.00375 .29023 L
s
0 .31528 m
.00375 .31528 L
s
0 .34033 m
.00375 .34033 L
s
0 .36537 m
.00375 .36537 L
s
0 .41547 m
.00375 .41547 L
s
0 .44051 m
.00375 .44051 L
s
0 .46556 m
.00375 .46556 L
s
0 .49061 m
.00375 .49061 L
s
0 .5407 m
.00375 .5407 L
s
0 .56575 m
.00375 .56575 L
s
0 .5908 m
.00375 .5908 L
s
0 .61584 m
.00375 .61584 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .46306 L
.16667 .46306 L
.16667 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .46306 L
.16667 .46306 L
.16667 .01472 L
0 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .55322 L
.33333 .55322 L
.33333 .01472 L
F
0 g
.16667 .01472 m
.16667 .55322 L
.33333 .55322 L
.33333 .01472 L
.16667 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .47307 L
.5 .47307 L
.5 .01472 L
F
0 g
.33333 .01472 m
.33333 .47307 L
.5 .47307 L
.5 .01472 L
.33333 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .12492 L
.66667 .12492 L
.66667 .01472 L
F
0 g
.5 .01472 m
.5 .12492 L
.66667 .12492 L
.66667 .01472 L
.5 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
F
0 g
.66667 .01472 m
.66667 .60332 L
.83333 .60332 L
.83333 .01472 L
.66667 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .37539 L
1 .37539 L
1 .01472 L
F
0 g
.83333 .01472 m
.83333 .37539 L
1 .37539 L
1 .01472 L
.83333 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?`3oool4000002P0oooo0P00
000[0?ooo`<00000:03oool2000002T0oooo0`00000[0?ooo`030000003oool0oooo0040oooo000o
0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo000002P0oooo00@000000?ooo`3oool00000:P3oool00`000000
oooo0?ooo`010?ooo`00@03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02L0oooo
1@00000Z0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000:P3oool00`000000
oooo0?ooo`010?ooo`00@@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0oooo
00@000000?ooo`3oool00000:@3oool2000002T0oooo0`00000/0?ooo`4000000@3oool10?ooo`00
?`3oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000002T0oooo00<000000?oo
o`000000:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00@000000?oo
o`3oool000000P3oool00400oooo0P00000Y0?ooo`800000:`3oool2000002T0oooo0`00000Y0?oo
o`<00000:03oool400000080oooo003o0?ooob40oooo000E0?ooo`030000003oool0oooo0?l0oooo
2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0ooooo`000009000000<0
oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`00
0?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`00
0?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<0
00000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y
0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y
0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0
003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0
003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l00003
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l00003
0000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000
:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000
:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o
0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o
0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003o
ool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o0000
0`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o0000
0`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`00
02T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`00
02T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo
0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000
o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000
o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`00
00<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`00
00<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo
000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0
000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0
000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<00000
0?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<00000
0?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?oo
o`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l0
00030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l0
00030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o
0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o
0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000
003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000
003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000
003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o
00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o
00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000
o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000
o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0
oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`00
0000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`00
0000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0
o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040
oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`00
0?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`00
0?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<0
00000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y
0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y
0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0
003o0000:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0
003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l00003
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l00003
0000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000
:03o00000`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000
:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o
0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003o
0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003o
ool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o0000
0`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o0000
0`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`00
02T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l002d00000:`3o00000`00
0000o`000?l0000Y0?l000030000003oool0oooo0040oooo000E0?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003oool0oooo02T0
oooo00<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040
oooo00080?ooo`800000103oool2000000D0oooo00<000000?l0003o0000:@3o00000`000000o`00
0?l0000X0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0:@3oool00`000000o`00
0?l0000Y0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool00@3oool000L0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003oool0oooo02T0
oooo00<000000?l0003o0000:@3o00000`000000o`000?l0000Y0?l000030000003oool0oooo0040
oooo000:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`010?ooo`00203oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000
o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`010?ooo`00203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?l0003o0000:@3o00000`000000o`000?l0000X0?l000030000003o0000o`0002T0
o`0000<000000?ooo`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002T0
o`0000<000000?ooo`3oool00@3oool000P0oooo0`0000030?ooo`8000001@3oool00`000000o`00
0?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y
0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`01
0?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l00003
0000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`00
5@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o
0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool0
0`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`00
02P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`00
02T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000
o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0
000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<00000
0?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<00000
0?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l0
00030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?oo
o`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?oo
o`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o
0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o
0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000
003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3o
ool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000
o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`00
0000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`00
0?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y
0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`01
0?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l00003
0000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`00
5@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o
0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool0
0`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`010?ooo`0000<0oooo0000000000000`0000020?ooo`800000103oool20000
00D0oooo00<000000?l0003o0000:@3o00000`000000o`000?l0000X0?l000030000003o0000o`00
02T0o`0000<000000?ooo`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003o0000o`00
02T0o`0000<000000?ooo`3oool00@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000o`000?l0000Y
0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`01
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o
00000`000000o`000?l0000Y0?l000030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o
00000`000000o`000?l0000Y0?l000030000003oool0oooo0040oooo00030?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?l0003o0000:@3o00000`000000o`000?l0000X0?l000030000003o0000o`0002T0o`00
00<000000?ooo`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002T0o`00
00<000000?ooo`3oool00@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000o`000?l0000Y0?l00003
0000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`00
0P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000o`000?l0000Y0?l000030000
003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3o
ool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000
o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`00
0000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`00
0?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y
0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`01
0?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0
003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l00003
0000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`00
5@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o
0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o
0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool0
0`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`00
02P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`00
02T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000
o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000
oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`00
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0
000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<00000
0?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<00000
0?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l0
00030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?oo
o`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?oo
o`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o
0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o
0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000
003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3o
ool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o
00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000
o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`00
0000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`010?ooo`005@3oool00`000000o`00
0?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:@3o00000`000000oooo
0?ooo`010?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`00;@00
00030?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<00000
0?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<00000
0?ooo`3oool0;@3oool000030?ooo`000000000000<000000P3oool2000000@0oooo0P0000050?oo
o`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l0
00030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o0000
0`000000o`000?l0000Y0?l000030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0]0?ooo`000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000o`000?l0000Y0?l000030000003o0000
o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002T0o`0000<000000?ooo`3oool0;@3oool000<0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000Y0?l000030000003o0000
o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002T0o`0000<000000?ooo`3oool0;@3oool000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?l0003o0000:@3o0000
0`000000o`000?l0000X0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0:@3oool0
0`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo00020?ooo`800000103oool30000
00<0oooo0P0000050?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`00
0000o`000?l0000Y0?l000030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`0]0?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0
o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0
o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?l0003o0000:@3o00000`000000o`00
0?l0000X0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0:@3oool00`000000o`00
0?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003o0000o`0002T0o`0000<0
00000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003oool0oooo02T0oooo00<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000o`000?l0000Y
0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?l0
003o0000:@3o00000`000000o`000?l0000X0?l000030000003o0000o`0002T0o`0000<000000?oo
o`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`03
0000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l00003
0000003oool0oooo02T0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`00
5@3oool00`000000o`000?l0000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000
:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0
;@3oool001D0oooo00<000000?l0003o0000:@3o00000`000000o`000?l0000X0?l000030000003o
0000o`0002T0o`0000<000000?ooo`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003o
ool0oooo02d0oooo000E0?ooo`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o0000
0`000000o`000?l0000Y0?l000030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0]0?ooo`005@3oool00`000000o`000?l0000Y0?l000030000003o0000o`00
02P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`030000003o0000o`00
02T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?l0003o0000:@3o00000`000000
o`000?l0000X0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0:@3oool00`000000
o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003o0000o`0002T0o`00
00<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l000030000003oool0oooo02T0oooo
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000o`000?l0
000Y0?l000030000003o0000o`0002P0o`0000<000000?l0003o0000:@3o00000`000000oooo0?oo
o`0Y0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<00000
0?l0003o0000:@3o00000`000000o`000?l0000X0?l000030000003o0000o`0002T0o`0000<00000
0?ooo`3oool0:@3oool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?oo
o`030000003o0000o`0002T0o`0000<000000?l0003o0000:03o00000`000000o`000?l0000Y0?l0
00030000003oool0oooo02T0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?oo
o`005@3oool]000002X0o`0000<000000?l0003o0000:@3o00000`000000oooo0?ooo`0Y0?ooo`03
0000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3oool0
:@3oool00`000000o`000?l0000X0?l000030000003o0000o`0002T0o`0000<000000?ooo`3oool0
:@3oool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003o
ool0oooo02T0oooo00<000000?l0003o0000:03o000]000002/0oooo00<000000?l0003o0000:@3o
00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`000?l0000Y0?l000030000003oool0
oooo02d0oooo000E0?ooo`030000003oool0oooo02T0oooo00<000000?l0003o0000:03o00000`00
0000oooo0?ooo`1E0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0
oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000X0?l000030000003oool0oooo05D0
oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`00
0?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`800000:P3oool00`000000o`000?l0
000X0?l000030000003oool0oooo05D0oooo00<000000?l0003o0000:@3o00000`000000oooo0?oo
o`0]0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002P0o`0000<00000
0?ooo`3oool0E@3oool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?oo
o`030000003oool0oooo02T0oooo00<000000?l0003o0000:03o00000`000000oooo0?ooo`1E0?oo
o`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3o
ool0:@3oool00`000000o`000?l0000X0?l000030000003oool0oooo05D0oooo00<000000?l0003o
0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003o0000o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`000?l0000Y0?l000030000
003oool0oooo02d0oooo00000`3oool0000000000002000000<0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003o0000o`0002P0o`0000<000000?ooo`3oool0E@3o
ool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo00000`3oool000000?ooo`04
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0Y0?ooo`030000003o0000o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`00
0?l0000Y0?l000030000003oool0oooo02d0oooo00020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`800000:P3oool00`000000
o`000?l0000X0?l000030000003oool0oooo05D0oooo00<000000?l0003o0000:@3o00000`000000
oooo0?ooo`0]0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?l0
003o0000:03o00000`000000oooo0?ooo`1E0?ooo`030000003o0000o`0002T0o`0000<000000?oo
o`3oool0;@3oool000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0
000X0?l000030000003oool0oooo05D0oooo00<000000?l0003o0000:@3o00000`000000oooo0?oo
o`0]0?ooo`000P3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003o0000o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`000?l0000Y
0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003oool0oooo02T0oooo00<000000?l0
003o0000:03o00000`000000oooo0?ooo`1E0?ooo`030000003o0000o`0002T0o`0000<000000?oo
o`3oool0;@3oool001D0oooo00<000000?ooo`3oool0:@3oool00`000000o`000?l0000X0?l00003
0000003oool0oooo05D0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`00
5@3oool2000002X0oooo00<000000?l0003o0000:03o00000`000000oooo0?ooo`1E0?ooo`030000
003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3oool0:@3o
ool00`000000o`000?l0000X0?l000030000003oool0oooo05D0oooo00<000000?l0003o0000:@3o
00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o0000
o`0002P0o`0000<000000?ooo`3oool0E@3oool00`000000o`000?l0000Y0?l000030000003oool0
oooo02d0oooo000E0?ooo`030000003oool0oooo02T0oooo;000001G0?ooo`030000003o0000o`00
02T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3oool0[03oool00`000000
o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003oool0oooo0:`0oooo
00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?oo
o`2/0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo0P00002]
0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?oo
o`3oool0[03oool00`000000o`000?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`03
0000003oool0oooo0:`0oooo00<000000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`00
5@3oool00`000000oooo0?ooo`2/0?ooo`030000003o0000o`0002T0o`0000<000000?ooo`3oool0
;@3oool001D0oooo00<000000?ooo`3oool0[03oool00`000000o`000?l0000Y0?l000030000003o
ool0oooo02d0oooo000E0?ooo`030000003oool0oooo0:`0oooo00<000000?l0003o0000:@3o0000
0`000000oooo0?ooo`0]0?ooo`005@3oool200000:d0oooo00<000000?l0003o0000:@3o00000`00
0000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`2/0?ooo`030000003o0000o`0002T0
o`0000<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3oool0[03oool00`000000o`00
0?l0000Y0?l000030000003oool0oooo02d0oooo000E0?ooo`030000003oool0oooo0:`0oooo00<0
00000?l0003o0000:@3o00000`000000oooo0?ooo`0]0?ooo`005@3oool00`000000oooo0?ooo`2/
0?ooobd00000;`3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.513876, -23.3437, \
0.0228385, 1.51971}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"BarChart", "[", 
        RowBox[{\(Thread[{probDist, Range[2, 7]}]\), ",", " ", 
          StyleBox[\(BarSpacing \[Rule] \(-0.2\)\),
            "MR",
            FontFamily->"Courier New",
            FontSize->12,
            FontWeight->"Bold",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False},
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->{True, False}}]}], 
        StyleBox["]",
          FontFamily->"Courier New",
          FontSize->12,
          FontWeight->"Bold",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}], 
      StyleBox[";",
        FontFamily->"Courier New",
        FontSize->12,
        FontWeight->"Bold",
        FontSlant->"Plain",
        FontColor->GrayLevel[0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0645161 0.16129 0.0147151 2.48226 [
[.09677 .00222 -3 -9 ]
[.09677 .00222 3 0 ]
[.25806 .00222 -3 -9 ]
[.25806 .00222 3 0 ]
[.41935 .00222 -3 -9 ]
[.41935 .00222 3 0 ]
[.58065 .00222 -3 -9 ]
[.58065 .00222 3 0 ]
[.74194 .00222 -3 -9 ]
[.74194 .00222 3 0 ]
[.90323 .00222 -3 -9 ]
[.90323 .00222 3 0 ]
[-0.0125 .13883 -24 -4.5 ]
[-0.0125 .13883 0 4.5 ]
[-0.0125 .26294 -18 -4.5 ]
[-0.0125 .26294 0 4.5 ]
[-0.0125 .38705 -24 -4.5 ]
[-0.0125 .38705 0 4.5 ]
[-0.0125 .51117 -18 -4.5 ]
[-0.0125 .51117 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09677 .01472 m
.09677 .02097 L
s
[(2)] .09677 .00222 0 1 Mshowa
.25806 .01472 m
.25806 .02097 L
s
[(3)] .25806 .00222 0 1 Mshowa
.41935 .01472 m
.41935 .02097 L
s
[(4)] .41935 .00222 0 1 Mshowa
.58065 .01472 m
.58065 .02097 L
s
[(5)] .58065 .00222 0 1 Mshowa
.74194 .01472 m
.74194 .02097 L
s
[(6)] .74194 .00222 0 1 Mshowa
.90323 .01472 m
.90323 .02097 L
s
[(7)] .90323 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .13883 m
.00625 .13883 L
s
[(0.05)] -0.0125 .13883 1 0 Mshowa
0 .26294 m
.00625 .26294 L
s
[(0.1)] -0.0125 .26294 1 0 Mshowa
0 .38705 m
.00625 .38705 L
s
[(0.15)] -0.0125 .38705 1 0 Mshowa
0 .51117 m
.00625 .51117 L
s
[(0.2)] -0.0125 .51117 1 0 Mshowa
.125 Mabswid
0 .03954 m
.00375 .03954 L
s
0 .06436 m
.00375 .06436 L
s
0 .08918 m
.00375 .08918 L
s
0 .11401 m
.00375 .11401 L
s
0 .16365 m
.00375 .16365 L
s
0 .18847 m
.00375 .18847 L
s
0 .2133 m
.00375 .2133 L
s
0 .23812 m
.00375 .23812 L
s
0 .28776 m
.00375 .28776 L
s
0 .31259 m
.00375 .31259 L
s
0 .33741 m
.00375 .33741 L
s
0 .36223 m
.00375 .36223 L
s
0 .41188 m
.00375 .41188 L
s
0 .4367 m
.00375 .4367 L
s
0 .46152 m
.00375 .46152 L
s
0 .48634 m
.00375 .48634 L
s
0 .53599 m
.00375 .53599 L
s
0 .56081 m
.00375 .56081 L
s
0 .58563 m
.00375 .58563 L
s
0 .61046 m
.00375 .61046 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01613 .01472 m
.01613 .43588 L
.17742 .43588 L
.17742 .01472 L
F
0 g
.5 Mabswid
.01613 .01472 m
.01613 .43588 L
.17742 .43588 L
.17742 .01472 L
.01613 .01472 L
s
1 0 0 r
.17742 .01472 m
.17742 .53823 L
.33871 .53823 L
.33871 .01472 L
F
0 g
.17742 .01472 m
.17742 .53823 L
.33871 .53823 L
.33871 .01472 L
.17742 .01472 L
s
1 0 0 r
.33871 .01472 m
.33871 .50712 L
.5 .50712 L
.5 .01472 L
F
0 g
.33871 .01472 m
.33871 .50712 L
.5 .50712 L
.5 .01472 L
.33871 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .09321 L
.66129 .09321 L
.66129 .01472 L
F
0 g
.5 .01472 m
.5 .09321 L
.66129 .09321 L
.66129 .01472 L
.5 .01472 L
s
1 0 0 r
.66129 .01472 m
.66129 .60332 L
.82258 .60332 L
.82258 .01472 L
F
0 g
.66129 .01472 m
.66129 .60332 L
.82258 .60332 L
.82258 .01472 L
.66129 .01472 L
s
1 0 0 r
.82258 .01472 m
.82258 .39277 L
.98387 .39277 L
.98387 .01472 L
F
0 g
.82258 .01472 m
.82258 .39277 L
.98387 .39277 L
.98387 .01472 L
.82258 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<P3oool4
000002L0oooo0P00000Y0?ooo`<000009P3oool2000002H0oooo0`00000Y0?ooo`030000003oool0
oooo01P0oooo000b0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000:@3oool0
0`000000oooo0?ooo`0T0?ooo`040000003oool0oooo000002D0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo0?ooo`0H0?ooo`00<`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02D0oooo1@00000X0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool00000
:03oool00`000000oooo0?ooo`0H0?ooo`00=03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02@0oooo00@000000?ooo`3oool000009`3oool2000002H0oooo0`00000Z0?ooo`030000
003oool0oooo01L0oooo000b0?ooo`040000003oool0oooo000002H0oooo00@000000?ooo`3oool0
00009`3oool00`000000oooo0000000W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09P3oool010000000oooo0?ooo`00000I0?ooo`00<`3oool2000002P0oooo0P00000Y0?ooo`80
00009`3oool3000002H0oooo0`00000V0?ooo`@000006@3oool00?l0oooo8@3oool001/0oooo00<0
00000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3ooooo000000H00000000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`00
0?l0000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`00
0?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D0
00000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o0000
9`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002H0o`0000<000000?l0003o0000
9`3o00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`00
00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`00
00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo
000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000
003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000V0?l000030000
003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo
0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`00
0?l0000W0?l000030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo
0?ooo`030?ooo`006`3oool200000080oooo00<000000?l0003o00009`3o00000`000000o`000?l0
000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0
000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D00000
0?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o
00000`000000o`000?l0000W0?l000030000003o0000o`0002H0o`0000<000000?l0003o00009`3o
00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<0
00000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<0
00000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K
0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o
0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000V0?l000030000003o
0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000
000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0
000W0?l000030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?oo
o`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o
00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009P3o
00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0
oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<0
00000?l0003o00009`3o00000`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<0
00000?ooo`3oool00`3oool001/0oooo0P0000020?ooo`030000003o0000o`0002L0o`0000<00000
0?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<00000
0?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?oo
o`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000V0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y
0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W
0?l000030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`03
0?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o0000
0`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009P3o0000
0`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo
0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<00000
0?l0003o00009`3o00000`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<00000
0?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000
o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool20000
0080oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`00
02L0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000V0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o000[000002P0o`0000<000000?l0
003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool00000
02T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo
02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo
00<0oooo000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3o
ool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0
003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0
003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`05
0000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool00`3oool001/0oooo0P0000020?ooo`030000003o0000o`0002L0
o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0
oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0
oooo000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l00003
0000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l00003
0000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0
oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o
00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o
00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo00020?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000002T0
o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0
oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0
000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0
000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo00<0oooo00001@3oool000000?ooo`3oool0000000P0oooo
00@000000?ooo`3oool000000`3oool2000000D0oooo00D000000?ooo`3oool0oooo0000000Y0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?oo
o`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o
00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o
00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo00020?ooo`8000002P3oool2
000000@0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0
000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0
000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D00000
0?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o
00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o
00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<0
00000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<0
00000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K
0?ooo`8000000P3oool00`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<00000
0?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<00000
0?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0
000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0
oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0
oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W
0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V
0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?oo
o`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o0000
0`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o0000
0`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<00000
0?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<00000
0?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?oo
o`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y
0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W
0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`03
0?ooo`006`3oool200000080oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3o
ool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0
003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0
003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`05
0000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?oo
o`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?oo
o`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`00
0000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`00
0000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`8000000P3oool00`000000
o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o
00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o
00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000
003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0
o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0
o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l00003
0000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`03
0000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`00
6`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000
o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000
o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`00
0000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3o
ool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3o
ool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0
o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0
o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool200000080oooo
00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`00
00<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`00
00<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000
003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000
003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3o
ool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`000000
:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool0
9`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool0
0`3oool000P0oooo0P0000040?ooo`8000000`3oool5000000<0oooo00D000000?ooo`3oool0oooo
0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo
0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo
0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o
00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o
00009`3o00000`000000oooo0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003o0000o`0002L0o`0000<000000?l0003o
00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o
00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo00070?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
02T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo
02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo
00<0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W
0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W
0?l000030000003oool0oooo00<0oooo00080?ooo`8000002P3oool2000000D0oooo00D000000?oo
o`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o0000
0`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o0000
0`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<00000
0?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<00000
0?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?oo
o`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y
0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W
0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`03
0?ooo`006`3oool200000080oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l0
00030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3o
ool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0
003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0
003o00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`05
0000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`00
02L0o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?oo
o`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?oo
o`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`00
0000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`00
0000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`8000000P3oool00`000000
o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o
00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o
00009P3o00000`000000o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000
003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0
o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0
o`0000<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l00003
0000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`03
0000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`00
6`3oool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000
o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000
o`000?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`00
0000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3o
ool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3o
ool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0
o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0
o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool200000080oooo
00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`00
00<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`00
00<000000?ooo`3oool00`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000
003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000
003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3o
ool01@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`00
0?l0000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`000000
:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool0
9`3oool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool0
0`3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`00
00<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`00
00<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?oo
o`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000
003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000
003oool0oooo00<0oooo000K0?ooo`8000000P3oool00`000000o`000?l0000W0?l000030000003o
0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o
0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool0
1@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0
000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0
000W0?l000030000003oool0oooo00<0oooo000K0?ooo`050000003oool0oooo0?ooo`000000:@3o
00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3o
ool00`000000o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3o
ool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<0
00000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<0
00000?l0003o00009`3o00000`000000oooo0?ooo`030?ooo`006`3oool01@000000oooo0?ooo`3o
ool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003o
ool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0000W0?l000030000003o
ool0oooo00<0oooo00020?ooo`800000103oool2000000<0oooo1@0000020?ooo`8000001@3oool0
1@000000oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0
000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000o`000?l0
000W0?l000030000003oool0oooo00<0oooo00001@3oool000000?ooo`3oool0000000X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?l0003o00009`3o00000`000000
oooo0?ooo`030?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?l0003o00009`3o00000`000000
o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000
o`000?l0000V0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool00`3oool000050?oo
o`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool01@000000
oooo0?ooo`3oool0000002T0o`0000<000000?l0003o00009`3o00000`000000o`000?l0000W0?l0
00030000003oool0oooo02L0oooo00<000000?l0003o00009P3o000[000000D0oooo00001@3oool0
00000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0
oooo02d0oooo00020?ooo`8000002P3oool2000000@0oooo0`0000040?ooo`050000003oool0oooo
0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<00000
0?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?oo
o`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W0?l000030000003o0000
o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0
oooo02d0oooo000K0?ooo`050000003oool0oooo0?ooo`000000:@3o00000`000000o`000?l0000W
0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V
0?l000030000003oool0oooo02d0oooo000K0?ooo`8000000P3oool00`000000o`000?l0000W0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?oo
o`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00D000000?ooo`3o
ool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0
oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0
003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?oo
o`3oool0;@3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l000030000003o0000o`00
02L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`00
02H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00D000000?ooo`3oool0oooo0000000Y0?l0
00030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?oo
o`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00D000000?ooo`3o
ool0oooo0000000Y0?l000030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`00
0000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0
oooo0P0000020?ooob/00000:@3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0
oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo
0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo
0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00<0
00000?ooo`3oool0:`3oool00`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<0
00000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K
0?ooo`030000003oool0oooo02/0oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W
0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]
0?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?l0
003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?oo
o`3oool0;@3oool001/0oooo00<000000?ooo`3oool0:`3oool00`000000o`000?l0000W0?l00003
0000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l00003
0000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo02/0oooo00<000000?l0003o0000
9`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o0000
9P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool2000002`0oooo00<000000?l0003o00009`3o
00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o
00000`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`030000003o0000
o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000
o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0:`3oool00`00
0000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`00
0000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo02/0
oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l000030000003oool0oooo02L0
oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo
0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?l0003o00009`3o00000`000000oooo
0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00<0
00000?ooo`3oool0:`3oool00`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<0
00000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K
0?ooo`800000;03oool00`000000o`000?l0000W0?l000030000003o0000o`0002L0o`0000<00000
0?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?oo
o`030000003oool0oooo02/0oooo00<000000?l0003o00009`3o00000`000000o`000?l0000W0?l0
00030000003oool0oooo02L0oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?oo
o`006`3oool00`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?l0003o
00009`3o00000`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3o
ool0;@3oool001/0oooo00<000000?ooo`3oool0:`3oool00`000000o`000?l0000W0?l000030000
003o0000o`0002L0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l0000V0?l000030000
003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo02/0oooo00<000000?l0003o00009`3o
00000`000000o`000?l0000W0?l000030000003oool0oooo02L0oooo00<000000?l0003o00009P3o
00000`000000oooo0?ooo`0]0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool0
0`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?l0003o00009`3o0000
0`000000oooo0?ooo`0W0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool0
00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02/0oooo00<000000?l0003o00009`3o000[000002T0oooo00<000000?l0003o00009P3o0000
0`000000oooo0?ooo`0]0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo0P00000/0?ooo`030000003o0000o`0002L0o`0000<000000?ooo`3oool0D@3oool0
0`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo00070?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003o0000
o`0002L0o`0000<000000?ooo`3oool0D@3oool00`000000o`000?l0000V0?l000030000003oool0
oooo02d0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?ooo`3oool0D@3o
ool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo00080?ooo`8000002P3oool2
000000D0oooo00<000000?ooo`3oool0:`3oool00`000000o`000?l0000W0?l000030000003oool0
oooo0540oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003o0000o`0002L0o`0000<000000?ooo`3oool0D@3oool00`00
0000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo02/0
oooo00<000000?l0003o00009`3o00000`000000oooo0?ooo`1A0?ooo`030000003o0000o`0002H0
o`0000<000000?ooo`3oool0;@3oool001/0oooo0P00000/0?ooo`030000003o0000o`0002L0o`00
00<000000?ooo`3oool0D@3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo
000K0?ooo`030000003oool0oooo02/0oooo:`00001C0?ooo`030000003o0000o`0002H0o`0000<0
00000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0Z@3oool00`000000o`000?l0000V
0?l000030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?l0
003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`2Y0?ooo`03
0000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0
Z@3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?ooo`030000003o
ool0oooo0:T0oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool2
00000:X0oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0
oooo00<000000?ooo`3oool0Z@3oool00`000000o`000?l0000V0?l000030000003oool0oooo02d0
oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?l0003o00009P3o00000`000000oooo
0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`2Y0?ooo`030000003o0000o`0002H0o`0000<0
00000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0Z@3oool00`000000o`000?l0000V
0?l000030000003oool0oooo02d0oooo000K0?ooo`800000ZP3oool00`000000o`000?l0000V0?l0
00030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo0:T0oooo00<000000?l0003o
00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`2Y0?ooo`030000
003o0000o`0002H0o`0000<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0Z@3o
ool00`000000o`000?l0000V0?l000030000003oool0oooo02d0oooo000K0?ooo`030000003oool0
oooo0:T0oooo00<000000?l0003o00009P3o00000`000000oooo0?ooo`0]0?ooo`006`3oool00`00
0000oooo0?ooo`2Y0?ooobX00000;`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.25039, -0.025181, \
0.0238691, 0.00155094}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{507, 600},
WindowMargins->{{204, Automatic}, {Automatic, 58}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 179, 6, 97, "Subtitle"],
Cell[2514, 84, 722, 16, 186, "Text"],
Cell[3239, 102, 54, 1, 30, "Input"],
Cell[3296, 105, 110, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[3431, 111, 60, 1, 30, "Input"],
Cell[3494, 114, 175, 3, 48, "Output"]
}, Open  ]],
Cell[3684, 120, 185, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[3894, 129, 66, 1, 30, "Input"],
Cell[3963, 132, 178, 3, 48, "Output"]
}, Open  ]],
Cell[4156, 138, 1135, 39, 134, "Text"],

Cell[CellGroupData[{
Cell[5316, 181, 54, 1, 30, "Input"],
Cell[5373, 184, 37, 1, 29, "Output"]
}, Open  ]],
Cell[5425, 188, 385, 14, 54, "Text"],

Cell[CellGroupData[{
Cell[5835, 206, 49, 1, 30, "Input"],
Cell[5887, 209, 37, 1, 29, "Output"]
}, Open  ]],
Cell[5939, 213, 1750, 55, 341, "Text"],

Cell[CellGroupData[{
Cell[7714, 272, 70, 1, 30, "Input"],
Cell[7787, 275, 153, 2, 29, "Output"]
}, Open  ]],
Cell[7955, 280, 86, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[8066, 285, 142, 3, 50, "Input"],
Cell[8211, 290, 21442, 1117, 186, 16094, 1046, "GraphicsData", "PostScript", \
"Graphics"],
Cell[29656, 1409, 130, 3, 29, "Output"]
}, Open  ]],
Cell[29801, 1415, 116, 2, 33, "Text"],
Cell[29920, 1419, 361, 6, 130, "Input"],
Cell[30284, 1427, 860, 24, 149, "Text"],

Cell[CellGroupData[{
Cell[31169, 1455, 167, 3, 110, "Input"],
Cell[31339, 1460, 23279, 1159, 186, 16328, 1069, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[54633, 2622, 377, 9, 90, "Text"],

Cell[CellGroupData[{
Cell[55035, 2635, 45, 1, 30, "Input"],
Cell[55083, 2638, 53, 1, 29, "Output"]
}, Open  ]],
Cell[55151, 2642, 79, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[55255, 2647, 278, 6, 90, "Input"],
Cell[55536, 2655, 23385, 1163, 186, 16365, 1072, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[78936, 3821, 1239, 35, 189, "Text"],

Cell[CellGroupData[{
Cell[80200, 3860, 92, 1, 30, "Input"],
Cell[80295, 3863, 35, 1, 29, "Output"]
}, Open  ]],
Cell[80345, 3867, 1480, 24, 318, "Text"],
Cell[81828, 3893, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[81919, 3898, 60, 1, 30, "Input"],
Cell[81982, 3901, 175, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82194, 3909, 384, 8, 230, "Input"],

Cell[CellGroupData[{
Cell[82603, 3921, 17262, 1130, 37, 13648, 1081, "GraphicsData", "PostScript", \
"Graphics"],
Cell[99868, 5053, 17268, 1130, 37, 13650, 1081, "GraphicsData", "PostScript", \
"Graphics"],
Cell[117139, 6185, 17340, 1131, 37, 13649, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[134482, 7318, 17369, 1131, 37, 13650, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[151854, 8451, 17283, 1130, 37, 13649, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[169140, 9583, 17376, 1132, 37, 13648, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[186519, 10717, 17432, 1132, 37, 13648, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[203954, 11851, 17467, 1133, 37, 13650, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[221424, 12986, 17272, 1130, 37, 13650, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[238699, 14118, 17264, 1130, 37, 13650, 1081, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[256012, 15254, 74, 0, 38, "Subsection"],
Cell[256089, 15256, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[256180, 15261, 80, 1, 30, "Input"],
Cell[256263, 15264, 175, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256475, 15272, 66, 1, 30, "Input"],
Cell[256544, 15275, 178, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256759, 15283, 239, 4, 110, "Input"],
Cell[257001, 15289, 64, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257102, 15295, 120, 2, 50, "Input"],
Cell[257225, 15299, 25756, 518, 186, 3099, 234, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[282996, 15820, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[283087, 15825, 80, 1, 30, "Input"],
Cell[283170, 15828, 175, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283382, 15836, 66, 1, 30, "Input"],
Cell[283451, 15839, 178, 3, 48, "Output"]
}, Open  ]],
Cell[283644, 15845, 246, 4, 110, "Input"],

Cell[CellGroupData[{
Cell[283915, 15853, 120, 2, 50, "Input"],
Cell[284038, 15857, 32545, 620, 186, 3353, 255, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[316598, 16480, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[316689, 16485, 80, 1, 30, "Input"],
Cell[316772, 16488, 175, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[316984, 16496, 66, 1, 30, "Input"],
Cell[317053, 16499, 178, 3, 48, "Output"]
}, Open  ]],
Cell[317246, 16505, 248, 4, 110, "Input"],

Cell[CellGroupData[{
Cell[317519, 16513, 120, 2, 50, "Input"],
Cell[317642, 16517, 33617, 626, 186, 3221, 246, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[351296, 17148, 1054, 30, 50, "Input"],
Cell[352353, 17180, 34670, 638, 186, 3318, 246, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

